@@ -66,16 +66,20 @@ BOOL APIENTRY About(HWND, unsigned int, unsigned int, long);
 #include "afsd_init.h"
 #ifdef DJGPP
 #include "afs/afsmsg95.h"
+#else
+#include "afsd_eventlog.h"
 #endif
 
 #include <afs/vldbint.h>
 #include <afs/afsint.h>
 
-#define AFS_DAEMON_SERVICE_NAME "TransarcAFSDaemon"
-#define AFS_DAEMON_EVENT_NAME "AFS Client"
+#define AFS_DAEMON_SERVICE_NAME AFSREG_CLT_SVC_NAME
+#define AFS_DAEMON_EVENT_NAME   AFSREG_CLT_SW_NAME
 
 void afs_exit();
 
+extern void afsi_log(char *pattern, ...);
+
 /* globals from the base afsd */
 
 extern int cm_logChunkSize;
@@ -125,12 +129,12 @@ extern long rx_mtu;
 
 extern HANDLE WaitToTerminate;
 
-#define CAPABILITY_ERRORTRANS (1<<0)
-#define CAPABILITY_BITS 1
-
-#define DFS_SUPPORT 1
+#undef  DFS_SUPPORT
 #define LOG_PACKET 1
 #undef  NOTSERVICE
+#define LOCK_TESTING 1
+
+#define WORKER_THREADS 10
 
 #define AFSD_HOOK_DLL  "afsdhook.dll"
 #define AFSD_INIT_HOOK "AfsdInitHook"
@@ -147,4 +151,6 @@ typedef BOOL ( APIENTRY * AfsdDaemonHook )(void);
 typedef BOOL ( APIENTRY * AfsdStoppingHook )(void);
 #define AFSD_STOPPED_HOOK "AfsdStoppedHook"
 typedef BOOL ( APIENTRY * AfsdStoppedHook )(void);
+
+#define SERVICE_CONTROL_CUSTOM_DUMP 128
 #endif /* AFSD_H_ENV */
