@@ -88,6 +88,13 @@ long cm_FlushFile(cm_scache_t *scp, cm_user_t *userp, cm_req_t *reqp)
 {
     long code;
 
+#ifdef AFS_FREELANCE_CLIENT
+    if ( scp->fid.cell == AFS_FAKE_ROOT_CELL_ID && scp->fid.volume == AFS_FAKE_ROOT_VOL_ID ) {
+	cm_noteLocalMountPointChange();
+	return 0;
+    }
+#endif
+
     lock_ObtainWrite(&scp->bufCreateLock);
     code = buf_FlushCleanPages(scp, userp, reqp);
         
@@ -110,7 +117,7 @@ long cm_FlushParent(cm_scache_t *scp, cm_user_t *userp, cm_req_t *reqp)
   
     /* now flush the file */
     code = cm_FlushFile(pscp, userp, reqp);
-    cm_ReleaseSCache(scp);
+    cm_ReleaseSCache(pscp);
 
     return code;
 }
@@ -122,6 +129,13 @@ long cm_FlushVolume(cm_user_t *userp, cm_req_t *reqp, afs_uint32 cell, afs_uint3
     cm_scache_t *scp;
     int i;
 
+#ifdef AFS_FREELANCE_CLIENT
+    if ( cell == AFS_FAKE_ROOT_CELL_ID && volume == AFS_FAKE_ROOT_VOL_ID ) {
+	cm_noteLocalMountPointChange();
+	return 0;
+    }
+#endif
+
     lock_ObtainWrite(&cm_scacheLock);
     for (i=0; i<cm_data.hashTableSize; i++) {
         for (scp = cm_data.hashTablep[i]; scp; scp = scp->nextp) {
@@ -2633,6 +2647,25 @@ long cm_IoctlGetSMBName(smb_ioctl_t *ioctlp, cm_user_t *userp)
   return 0;
 }
 
+long cm_IoctlUUIDControl(struct smb_ioctl * ioctlp, struct cm_user *userp)
+{
+    long cmd;
+    afsUUID uuid;
+
+    memcpy(&cmd, ioctlp->inDatap, sizeof(long));
+
+    if (cmd) {             /* generate a new UUID */
+        UuidCreate((UUID *) &uuid);
+        cm_data.Uuid = uuid;
+	cm_ForceNewConnectionsAllServers();
+    }
+
+    memcpy(ioctlp->outDatap, &cm_data.Uuid, sizeof(cm_data.Uuid));
+    ioctlp->outDatap += sizeof(cm_data.Uuid);
+
+    return 0;
+}
+
 /* 
  * functions to dump contents of various structures. 
  * In debug build (linked with crt debug library) will dump allocated but not freed memory
