@@ -1,110 +1,111 @@
 #include <windows.h>
+#include <tchar.h>
 #include "afsd.h"
 #include "cm_memmap.h"
 
 extern void afsi_log(char *pattern, ...);
 extern DWORD cm_ValidateCache;
 
-DWORD
-GranularityAdjustment(DWORD size)
+afs_uint64
+GranularityAdjustment(afs_uint64 size)
 {
     SYSTEM_INFO sysInfo;
-    static DWORD dwGranularity = 0;
+    static afs_uint64 qwGranularity = 0;
 
-    if ( !dwGranularity ) {
+    if ( !qwGranularity ) {
         GetSystemInfo(&sysInfo);
         afsi_log("Granularity - %lX", sysInfo.dwAllocationGranularity);
-        dwGranularity = sysInfo.dwAllocationGranularity;
+        qwGranularity = sysInfo.dwAllocationGranularity;
     }
 
-    size = (size + (dwGranularity - 1)) & ~(dwGranularity - 1);
+    size = (size + (qwGranularity - 1)) & ~(qwGranularity - 1);
     return size;
 }
 
-DWORD 
+afs_uint64 
 ComputeSizeOfConfigData(void)
 {
-    DWORD size;
+    afs_uint64 size;
     size = sizeof(cm_config_data_t);
     return size;
 }
 
-DWORD
+afs_uint64
 ComputeSizeOfVolumes(DWORD maxvols)
 {
-    DWORD size;
+    afs_uint64 size;
     size = maxvols * sizeof(cm_volume_t);
     return size;
 }
 
-DWORD
+afs_uint64
 ComputeSizeOfCells(DWORD maxcells)
 {
-    DWORD size;
+    afs_uint64 size;
     size = maxcells * sizeof(cm_cell_t);
     return size;
 }
 
-DWORD 
+afs_uint64 
 ComputeSizeOfACLCache(DWORD stats)
 {
-    DWORD size;
+    afs_uint64 size;
     size = 2 * (stats + 10) * sizeof(cm_aclent_t);
     return size;
 }
 
-DWORD 
+afs_uint64 
 ComputeSizeOfSCache(DWORD stats)
 {
-    DWORD size;
+    afs_uint64 size;
     size = (stats + 10) * sizeof(cm_scache_t);
     return size;
 }
 
-DWORD 
+afs_uint64 
 ComputeSizeOfSCacheHT(DWORD stats)
 {
-    DWORD size;
+    afs_uint64 size;
     size = (stats + 10) / 2 * sizeof(cm_scache_t *);;
     return size;
 }
 
-DWORD 
+afs_uint64 
 ComputeSizeOfDNLCache(void)
 {
-    DWORD size;
+    afs_uint64 size;
     size = NHSIZE * sizeof(cm_nc_t *) + NCSIZE * sizeof(cm_nc_t);
     return size;
 }
 
-DWORD 
-ComputeSizeOfDataBuffers(DWORD cacheBlocks, DWORD blockSize)
+afs_uint64 
+ComputeSizeOfDataBuffers(afs_uint64 cacheBlocks, DWORD blockSize)
 {
-    DWORD size;
+    afs_uint64 size;
     size = cacheBlocks * blockSize;
     return size;
 }
 
-DWORD 
+afs_uint64 
 ComputeSizeOfDataHT(void)
 {
-    DWORD size;
+    afs_uint64 size;
     size = osi_PrimeLessThan(CM_BUF_HASHSIZE) * sizeof(cm_buf_t *);
     return size;
 }
 
-DWORD 
-ComputeSizeOfDataHeaders(DWORD cacheBlocks)
+afs_uint64 
+ComputeSizeOfDataHeaders(afs_uint64 cacheBlocks)
 {
-    DWORD size;
+    afs_uint64 size;
     size = cacheBlocks * sizeof(cm_buf_t);
     return size;
 }
 
-DWORD
-ComputeSizeOfMappingFile(DWORD stats, DWORD maxVols, DWORD maxCells, DWORD chunkSize, DWORD cacheBlocks, DWORD blockSize)
+afs_uint64
+ComputeSizeOfMappingFile(DWORD stats, DWORD maxVols, DWORD maxCells, DWORD chunkSize, afs_uint64 cacheBlocks, DWORD blockSize)
 {
-    DWORD size;
+    afs_uint64 size;
     
     size       =  ComputeSizeOfConfigData()
                +  ComputeSizeOfVolumes(maxVols) 
@@ -229,6 +230,7 @@ cm_ShutdownMappedMemory(void)
     hMemoryMappedFile = NULL;
 
     afsi_log("Memory Mapped File has been closed");
+    return 0;
 }
 
 int
@@ -238,7 +240,7 @@ cm_ValidateMappedMemory(char * cachePath)
     PSECURITY_ATTRIBUTES psa;
     BY_HANDLE_FILE_INFORMATION fileInfo;
     int newFile = 1;
-    DWORD mappingSize;
+    afs_uint64 mappingSize;
     char * baseAddress = NULL;
     cm_config_data_t * config_data_p;
         
@@ -337,7 +339,8 @@ cm_ValidateMappedMemory(char * cachePath)
     hm = CreateFileMapping( hf,
                             NULL,
                             PAGE_READWRITE,
-                            0, mappingSize,
+			    (DWORD)(mappingSize >> 32), 
+			    (DWORD)(mappingSize & 0xFFFFFFFF),
                             NULL);
     if (hm == NULL) {
         if (GetLastError() == ERROR_DISK_FULL) {
@@ -354,15 +357,15 @@ cm_ValidateMappedMemory(char * cachePath)
     
     baseAddress = MapViewOfFileEx( hm,
                                    FILE_MAP_ALL_ACCESS,
-                                   0, 0,   
-                                   mappingSize,
+                                   0, 0,
+				   (SIZE_T)mappingSize,
                                    baseAddress );
     if (baseAddress == NULL) {
         fprintf(stderr, "Error mapping view of file: %d\n", GetLastError());
         baseAddress = MapViewOfFile( hm,
                                      FILE_MAP_ALL_ACCESS,
-                                     0, 0,   
-                                     mappingSize );
+                                     0, 0,
+				     (SIZE_T)mappingSize);
         if (baseAddress == NULL) {
             CloseHandle(hm);
             if (hf != INVALID_HANDLE_VALUE)
@@ -380,7 +383,7 @@ cm_ValidateMappedMemory(char * cachePath)
     config_data_p = (cm_config_data_t *) baseAddress;
 
     fprintf(stderr,"AFS Cache data:\n");
-    fprintf(stderr,"  Base Address   = %lX\n",baseAddress);
+    fprintf(stderr,"  Base Address   = %p\n",baseAddress);
     fprintf(stderr,"  stats          = %d\n", config_data_p->stats);
     fprintf(stderr,"  chunkSize      = %d\n", config_data_p->chunkSize);
     fprintf(stderr,"  blockSize      = %d\n", config_data_p->blockSize);
@@ -408,19 +411,199 @@ cm_ValidateMappedMemory(char * cachePath)
     return 0;
 }
 
+DWORD 
+GetVolSerialNumber(char * cachePath)
+{
+    char rootpath[128];
+    int  i = 0;
+    DWORD serial = 0;
+
+    if ( cachePath[0] == '\\' && cachePath[1] == '\\' ||
+	 cachePath[0] == '/' && cachePath[1] == '/' ) 
+    {
+	rootpath[0]=rootpath[1]='\\';
+	for ( i=2; cachePath[i]; i++ ) {
+	    rootpath[i] = cachePath[i];
+	    if ( cachePath[i] == '\\' || cachePath[i] == '/' ) {
+		i++;
+		break;
+	    }
+	}
+    } else if ( cachePath[1] == ':' ) {
+	rootpath[0] = cachePath[0];
+	rootpath[1] = ':';
+	i = 2;
+    }
+
+    for ( ; cachePath[i]; i++ ) {
+	rootpath[i] = cachePath[i];
+	if ( cachePath[i] == '\\' || cachePath[i] == '/' ) {
+	    i++;
+	    break;
+	}
+    }
+    rootpath[i] = '\0';
+
+    GetVolumeInformation(rootpath, NULL, 0, &serial, NULL, NULL, NULL, 0);
+    return serial;
+}
+
+BOOL GetTextualSid( PSID pSid, PBYTE TextualSid, LPDWORD lpdwBufferLen )
+{
+    PSID_IDENTIFIER_AUTHORITY psia;
+    DWORD dwSubAuthorities;
+    DWORD dwSidRev=SID_REVISION;
+    DWORD dwCounter;
+    DWORD dwSidSize;
+
+    // Validate the binary SID.
+    if(!IsValidSid(pSid)) 
+	return FALSE;
+
+    // Get the identifier authority value from the SID.
+
+    psia = GetSidIdentifierAuthority(pSid);
+
+    // Get the number of subauthorities in the SID.
+
+    dwSubAuthorities = *GetSidSubAuthorityCount(pSid);
+
+    // Compute the buffer length.
+    // S-SID_REVISION- + IdentifierAuthority- + subauthorities- + NULL
+
+    dwSidSize=(15 + 12 + (12 * dwSubAuthorities) + 1);
+
+    // Check input buffer length.
+    // If too small, indicate the proper size and set the last error.
+
+    if (TextualSid == NULL || *lpdwBufferLen < dwSidSize)
+    {
+        *lpdwBufferLen = dwSidSize;
+        SetLastError(ERROR_INSUFFICIENT_BUFFER);
+        return FALSE;
+    }
+
+    // Add 'S' prefix and revision number to the string.
+    dwSidSize=sprintf(TextualSid, "S-%lu-", dwSidRev );
+
+    // Add a SID identifier authority to the string.
+    if ( (psia->Value[0] != 0) || (psia->Value[1] != 0) )
+    {
+        dwSidSize+=sprintf(TextualSid + strlen(TextualSid),
+                    "0x%02hx%02hx%02hx%02hx%02hx%02hx",
+                    (USHORT)psia->Value[0],
+                    (USHORT)psia->Value[1],
+                    (USHORT)psia->Value[2],
+                    (USHORT)psia->Value[3],
+                    (USHORT)psia->Value[4],
+                    (USHORT)psia->Value[5]);
+    }
+    else
+    {
+        dwSidSize+=sprintf(TextualSid + strlen(TextualSid),
+                    "%lu",
+                    (ULONG)(psia->Value[5]      )   +
+                    (ULONG)(psia->Value[4] <<  8)   +
+                    (ULONG)(psia->Value[3] << 16)   +
+                    (ULONG)(psia->Value[2] << 24)   );
+    }
+
+    // Add SID subauthorities to the string.
+    //
+    for (dwCounter=0 ; dwCounter < dwSubAuthorities ; dwCounter++)
+    {
+        dwSidSize+=sprintf(TextualSid + dwSidSize, "-%lu",
+                    *GetSidSubAuthority(pSid, dwCounter) );
+    }
+
+    return TRUE;
+}
+
+PBYTE 
+IsSubAuthValid( PBYTE SidData, DWORD SidLength )
+{
+    PBYTE	sidPtr;
+
+    sidPtr = NULL;
+    if ( SidLength % sizeof(DWORD) == 0 )  {
+	for ( sidPtr = SidData + SidLength - 5*sizeof(DWORD); 
+	      sidPtr >= SidData; 
+	      sidPtr -= sizeof(DWORD) )
+	    if ( ((PDWORD)sidPtr)[1] == 0x05000000 &&  
+		 ((PDWORD)sidPtr)[2] == 0x00000015 )
+		break;
+	if ( sidPtr < SidData )
+	    sidPtr = NULL;
+    }
+    return sidPtr;
+}
+
+BOOL
+GetMachineSid(PBYTE SidBuffer, DWORD SidSize)
+{
+    HKEY  	hKey;
+    PBYTE 	vData;
+    DWORD 	dwType;
+    DWORD 	dwLen;
+    PBYTE 	pSid;
+    DWORD 	dwStatus;
+
+    if (!SidBuffer)
+	return FALSE;
+
+    //
+    // Read the last subauthority of the current computer SID
+    //
+    if( RegOpenKey( HKEY_LOCAL_MACHINE, "SECURITY\\SAM\\Domains\\Account", 
+		    &hKey) != ERROR_SUCCESS ) {
+	return FALSE;
+    }
+    dwLen = 0;
+    vData = NULL;
+    RegQueryValueEx( hKey, "V", NULL, &dwType, vData, &dwLen );
+    vData = (PBYTE) malloc( dwLen );
+    dwStatus = RegQueryValueEx( hKey, "V", NULL, &dwType, vData, &dwLen );
+    RegCloseKey( hKey );
+    if( dwStatus != ERROR_SUCCESS ) {
+	return FALSE;
+    }
+
+    //
+    // Make sure that we're dealing with a SID we understand
+    //
+    pSid = IsSubAuthValid( vData, dwLen );
+
+    if( !pSid || SidSize < dwLen - (pSid - vData)) {
+	free(vData);
+	return FALSE;
+    }
+
+    memset(SidBuffer, 0, SidSize);
+    memcpy(SidBuffer, pSid, dwLen - (pSid - vData) );
+    free(vData);
+    return TRUE;
+}
+
 int
-cm_InitMappedMemory(DWORD virtualCache, char * cachePath, DWORD stats, DWORD chunkSize, DWORD cacheBlocks)
+cm_InitMappedMemory(DWORD virtualCache, char * cachePath, DWORD stats, DWORD chunkSize, afs_uint64 cacheBlocks)
 {
     HANDLE hf = INVALID_HANDLE_VALUE, hm;
     PSECURITY_ATTRIBUTES psa;
     int newFile = 1;
-    DWORD mappingSize;
+    afs_uint64 mappingSize;
     DWORD maxVols = stats/2;
     DWORD maxCells = stats/4;
+    DWORD volumeSerialNumber = 0;
+    DWORD sidStringSize = 0;
+    DWORD rc;
+    CHAR  machineSid[6 * sizeof(DWORD)]="";
     char * baseAddress = NULL;
     cm_config_data_t * config_data_p;
     char * p;
 
+    volumeSerialNumber = GetVolSerialNumber(cachePath);
+    GetMachineSid(machineSid, sizeof(machineSid));
+
     mappingSize = ComputeSizeOfMappingFile(stats, maxVols, maxCells, chunkSize, cacheBlocks, CM_CONFIGDEFAULT_BLOCKSIZE);
 
     if ( !virtualCache ) {
@@ -448,10 +631,14 @@ cm_InitMappedMemory(DWORD virtualCache, char * cachePath, DWORD stats, DWORD chu
             afsi_log("Cache File \"%s\" already exists", cachePath);
 
             if ( GetFileInformationByHandle(hf, &fileInfo) ) {
+		afs_uint64 filesize;
                 afsi_log("Existing File Size: %08X:%08X",
                           fileInfo.nFileSizeHigh,
                           fileInfo.nFileSizeLow);
-                if (fileInfo.nFileSizeLow > GranularityAdjustment(mappingSize)) {
+		filesize = fileInfo.nFileSizeHigh;
+		filesize <<= 32;
+		filesize += fileInfo.nFileSizeLow;
+                if (filesize > GranularityAdjustment(mappingSize)) {
                     psa = CreateCacheFileSA();
                     hf = CreateFile( cachePath,
                                      GENERIC_READ | GENERIC_WRITE,
@@ -474,7 +661,6 @@ cm_InitMappedMemory(DWORD virtualCache, char * cachePath, DWORD stats, DWORD chu
                               fileInfo.nFileSizeHigh,
                               fileInfo.nFileSizeLow);
                 }
-
             }
 
             hm = CreateFileMapping( hf,
@@ -491,8 +677,8 @@ cm_InitMappedMemory(DWORD virtualCache, char * cachePath, DWORD stats, DWORD chu
                     hm = CreateFileMapping( hf,
                                             NULL,
                                             PAGE_READWRITE,
-                                            0, 
-                                            mappingSize,
+                                            (DWORD)(mappingSize >> 32), 
+                                            (DWORD)(mappingSize & 0xFFFFFFFF),
                                             NULL);
                     if (hm == NULL) {
                         if (GetLastError() == ERROR_DISK_FULL) {
@@ -553,7 +739,8 @@ cm_InitMappedMemory(DWORD virtualCache, char * cachePath, DWORD stats, DWORD chu
     hm = CreateFileMapping( hf,
                             NULL,
                             PAGE_READWRITE,
-                            0, mappingSize,
+			    (DWORD)(mappingSize >> 32), 
+			    (DWORD)(mappingSize & 0xFFFFFFFF),
                             NULL);
     if (hm == NULL) {
         if (GetLastError() == ERROR_DISK_FULL) {
@@ -567,15 +754,17 @@ cm_InitMappedMemory(DWORD virtualCache, char * cachePath, DWORD stats, DWORD chu
     }
     baseAddress = MapViewOfFileEx( hm,
                                    FILE_MAP_ALL_ACCESS,
-                                   0, 0,   
-                                   mappingSize,
+                                   0, 
+				   0, 
+				   (SIZE_T)mappingSize,
                                    baseAddress );
     if (baseAddress == NULL) {
         afsi_log("Error mapping view of file: %d", GetLastError());
         baseAddress = MapViewOfFile( hm,
                                      FILE_MAP_ALL_ACCESS,
-                                     0, 0,   
-                                     mappingSize );
+                                     0, 
+				     0, 
+				     (SIZE_T)mappingSize);
         if (baseAddress == NULL) {
             if (hf != INVALID_HANDLE_VALUE)
                 CloseHandle(hf);
@@ -644,10 +833,52 @@ cm_InitMappedMemory(DWORD virtualCache, char * cachePath, DWORD stats, DWORD chu
         cm_data.bufDataBaseAddress = (char *) baseAddress;
         baseAddress += ComputeSizeOfDataBuffers(cacheBlocks, CM_CONFIGDEFAULT_BLOCKSIZE);
         cm_data.bufEndOfData = (char *) baseAddress;
-
         cm_data.fakeDirVersion = 0x8;
-
         UuidCreate((UUID *)&cm_data.Uuid);
+	cm_data.volSerialNumber = volumeSerialNumber;
+	memcpy(cm_data.Sid, machineSid, sizeof(machineSid));
+    } else {
+	int gennew = 0;
+
+	if ( volumeSerialNumber == 0 || volumeSerialNumber != cm_data.volSerialNumber ) {
+	    gennew = 1;
+	    afsi_log("Volume serial number change, generating new UUID");
+	    afsi_log("Old volume Serial Number: 0x%x", cm_data.volSerialNumber);
+	} else if ( machineSid[0] && memcmp(machineSid, cm_data.Sid, sizeof(machineSid))) {
+	    gennew = 1;
+	    afsi_log("Machine Sid changed, generating new UUID");
+	    GetTextualSid( (PSID)cm_data.Sid, NULL, &sidStringSize );
+	    if (sidStringSize) {
+		p = malloc(sidStringSize * sizeof(TCHAR));
+		if (p) {
+		    rc = GetTextualSid( (PSID)cm_data.Sid, p, &sidStringSize );
+		    afsi_log("Old Machine SID: %s", rc ? p : "unknown");
+		    free(p);
+		}
+	    } else {
+		afsi_log("Old Machine SID: unknown");
+	    }
+	}
+
+	if (gennew) {
+	    UuidCreate((UUID *)&cm_data.Uuid);
+	    cm_data.volSerialNumber = volumeSerialNumber;
+	    memcpy(cm_data.Sid, machineSid, sizeof(machineSid));
+	}
+    }
+
+    afsi_log("Volume Serial Number: 0x%x", cm_data.volSerialNumber);
+
+    GetTextualSid( (PSID)cm_data.Sid, NULL, &sidStringSize );
+    if (sidStringSize) {
+	p = malloc(sidStringSize * sizeof(TCHAR));
+	if (p) {
+	    rc = GetTextualSid( (PSID)cm_data.Sid, p, &sidStringSize );
+	    afsi_log("Machine SID: %s", rc ? p : "unknown");
+	    free(p);
+	}
+    } else {
+	afsi_log("Machine SID: unknown");
     }
 
     UuidToString((UUID *)&cm_data.Uuid, &p);
