@@ -82,14 +82,19 @@ typedef struct cm_cacheParms {
 #define VIOCNEWGETTOK			0x1f
 #define VIOCDELTOK			0x20
 #define VIOCDELALLTOK			0x21
-
+#define VIOC_ISSYMLINK			0x22
 #define VIOC_SYMLINK			0x23
 #define VIOC_LISTSYMLINK		0x24
 #define VIOC_DELSYMLINK			0x25
 #define VIOC_MAKESUBMOUNT		0x26
-#define VIOC_SHUTDOWN                   0x27
-
 #define VIOC_GETRXKCRYPT		0x27
 #define VIOC_SETRXKCRYPT		0x28
-
+#define VIOC_TRACEMEMDUMP               0x29
+#define VIOC_SHUTDOWN                   0x2a
+#define VIOC_FLUSHALL                   0x2b
+#define VIOCGETFID                      0x2c
+#define VIOCGETOWNER                    0x2d
+#define VIOC_RXSTAT_PROC                0x2e
+#define VIOC_RXSTAT_PEER                0x2f
+#define VIOC_UUIDCTL                    0x30
 #endif /*  __SMB_IOCONS_H_ENV_ */
