@@ -64,6 +64,13 @@
 #include <linux/init.h>
 #include <linux/unistd.h>
 #include <linux/mm.h>
+#ifdef AFS_LINUX26_ENV
+#include <scsi/scsi.h> /* for scsi_command_size */
+#endif
+
+#if defined(AFS_PPC64_LINUX26_ENV)
+#include <asm/abs_addr.h>
+#endif
 
 #ifdef AFS_AMD64_LINUX20_ENV
 #include <asm/ia32_unistd.h>
@@ -78,6 +85,8 @@
 /* lower bound of valid kernel text pointers */
 #ifdef AFS_IA64_LINUX20_ENV
 #define ktxt_lower_bound (((unsigned long)&kernel_thread )  & 0xfff00000L)
+#elif defined(AFS_PPC64_LINUX20_ENV)
+#define ktxt_lower_bound (KERNELBASE)
 #else
 #define ktxt_lower_bound (((unsigned long)&kernel_thread )  & ~0xfffffL)
 #endif
@@ -101,19 +110,35 @@
 #define _SX(x) (x)
 #endif
 
+/* Older Linux doesn't have __user. The sys_read prototype needs it. */
+#ifndef __user
+#define __user
+#endif
 
 /* Allow the user to specify sys_call_table addresses */
 static unsigned long sys_call_table_addr[4] = { 0,0,0,0 };
+#if defined(module_param_array) && LINUX_VERSION_CODE > KERNEL_VERSION(2,6,9)
+module_param_array(sys_call_table_addr, long, NULL, 0);
+#else
 MODULE_PARM(sys_call_table_addr, "1-4l");
+#endif
 MODULE_PARM_DESC(sys_call_table_addr, "Location of system call tables");
 
 /* If this is set, we are more careful about avoiding duplicate matches */
 static int probe_carefully = 1;
+#ifdef module_param
+module_param(probe_carefully, int, 0);
+#else
 MODULE_PARM(probe_carefully, "i");
+#endif
 MODULE_PARM_DESC(probe_carefully, "Probe for system call tables carefully");
 
 static int probe_ignore_syscalls[8] = { -1, -1, -1, -1, -1, -1, -1, -1 };
+#if defined(module_param_array) && LINUX_VERSION_CODE > KERNEL_VERSION(2,6,9)
+module_param_array(probe_ignore_syscalls, int, NULL, 0);
+#else
 MODULE_PARM(probe_ignore_syscalls, "1-8i");
+#endif
 MODULE_PARM_DESC(probe_ignore_syscalls, "Syscalls to ignore in table checks");
 
 #ifdef OSI_PROBE_DEBUG
@@ -128,19 +153,35 @@ MODULE_PARM_DESC(probe_ignore_syscalls, "Syscalls to ignore in table checks");
  * 0x0040 - automatically ignore setgroups and afs_syscall
  */
 static int probe_debug = 0x41;
+#ifdef module_param
+module_param(probe_debug, int, 0);
+#else
 MODULE_PARM(probe_debug, "i");
+#endif
 MODULE_PARM_DESC(probe_debug, "Debugging level");
 
 static unsigned long probe_debug_addr[4] = { 0,0,0,0 };
+#if defined(module_param_array) && LINUX_VERSION_CODE > KERNEL_VERSION(2,6,9)
+module_param_array(probe_debug_addr, long, NULL, 0);
+#else
 MODULE_PARM(probe_debug_addr, "1-4l");
+#endif
 MODULE_PARM_DESC(probe_debug_addr, "Debug range starting locations");
 
 static unsigned long probe_debug_range = 0;
+#ifdef module_param
+module_param(probe_debug_range, long, 0);
+#else
 MODULE_PARM(probe_debug_range, "l");
+#endif
 MODULE_PARM_DESC(probe_debug_range, "Debug range length");
 
 static unsigned long probe_debug_tag = 0;
+#ifdef module_param
+module_param(probe_debug_tag, long, 0);
+#else
 MODULE_PARM(probe_debug_tag, "l");
+#endif
 MODULE_PARM_DESC(probe_debug_tag, "Debugging output start tag");
 #endif
 
@@ -188,6 +229,7 @@ extern SYSCALLTYPE ia32_sys_call_table[] __attribute__((weak));
 extern SYSCALLTYPE sys_call_table32[] __attribute__((weak));
 extern SYSCALLTYPE sys_call_table_emu[] __attribute__((weak));
 
+extern asmlinkage ssize_t sys_read(unsigned int fd, char __user * buf, size_t count) __attribute__((weak));
 extern asmlinkage long sys_close(unsigned int) __attribute__((weak));
 extern asmlinkage long sys_chdir(const char *) __attribute__((weak));
 extern asmlinkage ssize_t sys_write(unsigned int, const char *, size_t) __attribute__((weak));
@@ -233,6 +275,11 @@ typedef struct {
     unsigned long try_base_mask;    /* base address bits to force to zero */
     unsigned long try_length;       /* default length for scan */
 
+    unsigned long alt_try_sect_sym;     /* symbol in section to try scanning */
+    unsigned long alt_try_base;         /* default base address for scan */
+    unsigned long alt_try_base_mask;    /* base address bits to force to zero */
+    unsigned long alt_try_length;       /* default length for scan */
+
     int n_zapped_syscalls;          /* number of unimplemented system calls */
     int *zapped_syscalls;           /* list of unimplemented system calls */
 
@@ -480,6 +527,10 @@ static probectl main_probe = {
     (unsigned long)(&tasklist_lock) - 0x30000,
     0,
     0x6000,
+#elif defined(AFS_PPC64_LINUX26_ENV)
+    (unsigned long)(&do_signal),
+    0xfff,
+    0x400,
 #elif defined(AFS_PPC_LINUX20_ENV) || defined(AFS_PPC_LINUX20_ENV)
     (unsigned long)&init_mm,
     0xffff,
@@ -490,6 +541,15 @@ static probectl main_probe = {
     16384,
 #endif
 
+#ifdef AFS_LINUX26_ENV
+    (unsigned long)scsi_command_size,
+    (unsigned long)scsi_command_size,
+    0x3ffff,
+    0x30000,
+#else
+    0, 0, 0, 0,
+#endif
+
     /* number and list of unimplemented system calls */
     ((sizeof(main_zapped_syscalls)/sizeof(main_zapped_syscalls[0])) - 1),
     main_zapped_syscalls,
@@ -577,6 +637,16 @@ static probectl ia32_probe = {
     0,
     (0x180000 / sizeof(unsigned long *)),
 
+#ifdef AFS_LINUX26_ENV
+    (unsigned long)scsi_command_size,
+    (unsigned long)scsi_command_size,
+    0x3ffff,
+    0x30000,
+#else
+    0, 0, 0, 0,
+#endif
+
+
     /* number and list of unimplemented system calls */
     ((sizeof(ia32_zapped_syscalls)/sizeof(ia32_zapped_syscalls[0])) - 1),
     ia32_zapped_syscalls,
@@ -617,6 +687,10 @@ static probectl *probe_list[] = {
 
 /********** Probing Configuration: ppc64, sparc64 sys_call_table32 **********/
 #elif defined(AFS_PPC64_LINUX20_ENV) || defined(AFS_SPARC64_LINUX20_ENV)
+struct fptr {
+    void *ip;
+    unsigned long gp;
+};
 
 /* 
  * syscall pairs/triplets to probe
@@ -692,12 +766,25 @@ static probectl sct32_probe = {
     (unsigned long)(&sys_close),
     0xfffff,
     0x10000,
+#elif defined(AFS_PPC64_LINUX26_ENV)
+    (unsigned long)(&do_signal),
+    0xfff,
+    0x400,
 #else
     (unsigned long)&init_mm,
     0,
     16384,
 #endif
 
+#ifdef AFS_LINUX26_ENV
+    (unsigned long)scsi_command_size,
+    (unsigned long)scsi_command_size,
+    0x3ffff,
+    0x30000,
+#else
+    0, 0, 0, 0,
+#endif
+
     /* number and list of unimplemented system calls */
     ((sizeof(sct32_zapped_syscalls)/sizeof(sct32_zapped_syscalls[0])) - 1),
     sct32_zapped_syscalls,
@@ -784,6 +871,15 @@ static probectl emu_probe = {
     0xfffff,
     0x20000,
 
+#ifdef AFS_LINUX26_ENV
+    (unsigned long)scsi_command_size,
+    (unsigned long)scsi_command_size,
+    0x3ffff,
+    0x30000,
+#else
+    0, 0, 0, 0,
+#endif
+
     /* number and list of unimplemented system calls */
     ((sizeof(emu_zapped_syscalls)/sizeof(emu_zapped_syscalls[0])) - 1),
     emu_zapped_syscalls,
@@ -859,7 +955,7 @@ static int check_table(probectl *P, PROBETYPE *ptr)
     return -1;
 }
 
-static void *try(probectl *P, tryctl *T, PROBETYPE *ptr,
+static void *try(probectl *P, tryctl *T, PROBETYPE *aptr,
 		 unsigned long datalen)
 {
 #ifdef OSI_PROBE_KALLSYMS
@@ -870,8 +966,9 @@ static void *try(probectl *P, tryctl *T, PROBETYPE *ptr,
 #endif
     unsigned long offset, ip1, ip2, ip3;
     int ret;
+    PROBETYPE *ptr;
 
-#ifdef AFS_IA64_LINUX20_ENV
+#if defined(AFS_IA64_LINUX20_ENV) || defined(AFS_PPC64_LINUX20_ENV)
     ip1 = T->fn1 ? (unsigned long)((struct fptr *)T->fn1)->ip : 0;
     ip2 = T->fn2 ? (unsigned long)((struct fptr *)T->fn2)->ip : 0;
     ip3 = T->fn3 ? (unsigned long)((struct fptr *)T->fn3)->ip : 0;
@@ -890,11 +987,19 @@ static void *try(probectl *P, tryctl *T, PROBETYPE *ptr,
     if (!ip1 || !ip2 || (T->NR3 >= 0 && !ip3))
 	return 0;
 
-    for (offset = 0; offset < datalen; offset++, ptr++) {
+    for (offset = 0; offset < datalen; offset++, aptr++) {
+#if defined(AFS_PPC64_LINUX20_ENV)
+	ptr = (PROBETYPE*)(*aptr);
+	if ((unsigned long)ptr <= KERNELBASE) {
+		continue;
+	}
+#else
+	ptr = aptr;
+#endif
 	ret = check_table(P, ptr);
 	if (ret >= 0) {
 	    /* return value is number of entries to skip */
-	    ptr    += ret;
+	    aptr    += ret;
 	    offset += ret;
 	    continue;
 	}
@@ -957,7 +1062,7 @@ static int check_harder(probectl *P, PROBETYPE *p)
 	}
     }
 
-#ifdef AFS_IA64_LINUX20_ENV
+#if defined(AFS_IA64_LINUX20_ENV) || defined(AFS_PPC64_LINUX20_ENV)
     ip1 = P->verify_fn ? (unsigned long)((struct fptr *)(P->verify_fn))->ip : 0;
 #else
     ip1 = (unsigned long)(P->verify_fn);
@@ -1059,6 +1164,66 @@ static void *try_harder(probectl *P, PROBETYPE *ptr, unsigned long datalen)
     }                           \
 } while (0)
 #endif
+static void *scan_for_syscall_table(probectl *P, PROBETYPE *B, unsigned long L)
+{
+    tryctl *T;
+    void *answer;
+#if defined(AFS_S390_LINUX20_ENV) || defined(AFS_S390X_LINUX20_ENV)
+    void *answer2;
+#endif
+#ifdef OSI_PROBE_DEBUG
+    void *final_answer = 0;
+#endif
+#ifdef OSI_PROBE_DEBUG
+    if (probe_debug & 0x0007)
+	printk("<7>osi_probe: %s                      base=0x%lx, len=0x%lx\n",
+	       P->symbol, (unsigned long)B, L);
+    if (probe_debug & 0x0009) {
+	printk("<7>osi_probe: %s                      ktxt_lower_bound=0x%lx\n",
+	       P->symbol, ktxt_lower_bound);
+	printk("<7>osi_probe: %s                      NR_syscalls=%d\n",
+	       P->symbol, NR_syscalls);
+    }
+#endif
+
+    for (T = P->trylist; T->name; T++) {
+	answer = try(P, T, B, L);
+#if defined(AFS_S390_LINUX20_ENV) || defined(AFS_S390X_LINUX20_ENV)
+	answer2 = try(P, T, (PROBETYPE *)(2 + (void *)B), L);
+#ifdef OSI_PROBE_DEBUG
+	if (probe_debug & 0x0003) {
+	    printk("<7>osi_probe: %s = 0x%016lx %s (even)\n",
+		   P->symbol, (unsigned long)(answer), T->name);
+	    printk("<7>osi_probe: %s = 0x%016lx %s (odd)\n",
+		   P->symbol, (unsigned long)(answer2), T->name);
+	}
+#endif
+	if (answer && answer2) answer = 0;
+	else if (answer2) answer = answer2;
+#endif
+	if (answer)
+	    return answer;
+    }
+
+    /* XXX more checks here */
+
+    answer = try_harder(P, B, L);
+#if defined(AFS_S390_LINUX20_ENV) || defined(AFS_S390X_LINUX20_ENV)
+    answer2 = try_harder(P, (PROBETYPE *)(2 + (void *)B), L);
+#ifdef OSI_PROBE_DEBUG
+    if (probe_debug & 0x0005) {
+	printk("<7>osi_probe: %s = 0x%016lx pattern scan (even)\n",
+	       P->symbol, (unsigned long)(answer));
+	printk("<7>osi_probe: %s = 0x%016lx pattern scan (odd)\n",
+	       P->symbol, (unsigned long)(answer2));
+    }
+#endif
+    if (answer && answer2) answer = 0;
+    else if (answer2) answer = answer2;
+#endif
+    return answer;
+}
+
 static void *do_find_syscall_table(probectl *P, char **method)
 {
 #ifdef OSI_PROBE_KALLSYMS
@@ -1071,11 +1236,7 @@ static void *do_find_syscall_table(probectl *P, char **method)
 #endif
     PROBETYPE *B;
     unsigned long L;
-    tryctl *T;
     void *answer;
-#if defined(AFS_S390_LINUX20_ENV) || defined(AFS_S390X_LINUX20_ENV)
-    void *answer2;
-#endif
 #ifdef OSI_PROBE_DEBUG
     void *final_answer = 0;
 #endif
@@ -1123,55 +1284,28 @@ static void *do_find_syscall_table(probectl *P, char **method)
 	}
     }
 #endif
-
-#ifdef OSI_PROBE_DEBUG
-    if (probe_debug & 0x0007)
-	printk("<7>osi_probe: %s                      base=0x%lx, len=0x%lx\n",
-	       P->symbol, (unsigned long)B, L);
-    if (probe_debug & 0x0009) {
-	printk("<7>osi_probe: %s                      ktxt_lower_bound=0x%lx\n",
-	       P->symbol, ktxt_lower_bound);
-	printk("<7>osi_probe: %s                      NR_syscalls=%d\n",
-	       P->symbol, NR_syscalls);
-    }
-#endif
-
-    for (T = P->trylist; T->name; T++) {
-	answer = try(P, T, B, L);
-#if defined(AFS_S390_LINUX20_ENV) || defined(AFS_S390X_LINUX20_ENV)
-	answer2 = try(P, T, (PROBETYPE *)(2 + (void *)B), L);
-#ifdef OSI_PROBE_DEBUG
-	if (probe_debug & 0x0003) {
-	    printk("<7>osi_probe: %s = 0x%016lx %s (even)\n",
-		   P->symbol, (unsigned long)(answer), T->name);
-	    printk("<7>osi_probe: %s = 0x%016lx %s (odd)\n",
-		   P->symbol, (unsigned long)(answer2), T->name);
-	}
-#endif
-	if (answer && answer2) answer = 0;
-	else if (answer2) answer = answer2;
-#endif
-        check_result(answer, T->name);
-    }
-
-    /* XXX more checks here */
-
-    answer = try_harder(P, B, L);
-#if defined(AFS_S390_LINUX20_ENV) || defined(AFS_S390X_LINUX20_ENV)
-    answer2 = try_harder(P, (PROBETYPE *)(2 + (void *)B), L);
-#ifdef OSI_PROBE_DEBUG
-    if (probe_debug & 0x0005) {
-	printk("<7>osi_probe: %s = 0x%016lx pattern scan (even)\n",
-	       P->symbol, (unsigned long)(answer));
-	printk("<7>osi_probe: %s = 0x%016lx pattern scan (odd)\n",
-	       P->symbol, (unsigned long)(answer2));
-    }
-#endif
-    if (answer && answer2) answer = 0;
-    else if (answer2) answer = answer2;
-#endif
+   
+    answer = scan_for_syscall_table(P, B, L);
     check_result(answer, "pattern scan");
-
+    B = (PROBETYPE *)((P->alt_try_base) & ~(P->alt_try_base_mask));
+    L = P->alt_try_length;
+    /* Now, see if the kernel will tell us something better than the default */
+#ifdef OSI_PROBE_KALLSYMS
+    if (kallsyms_address_to_symbol && P->alt_try_sect_sym) {
+	ret = kallsyms_address_to_symbol(P->alt_try_sect_sym,
+					 &mod_name, &mod_start, &mod_end,
+					 &sec_name, &sec_start, &sec_end,
+					 &sym_name, &sym_start, &sym_end);
+	if (ret) {
+	    B = (PROBETYPE *)sec_start;
+	    L = (sec_end - sec_start) / sizeof(unsigned long);
+	}
+    }
+#endif
+    if (B && L) {
+	answer = scan_for_syscall_table(P, B, L);
+	check_result(answer, "pattern scan");
+    }
 #ifdef OSI_PROBE_DEBUG
     return final_answer;
 #else
@@ -1179,6 +1313,38 @@ static void *do_find_syscall_table(probectl *P, char **method)
 #endif
 }
 
+#if defined(AFS_I386_LINUX26_ENV) || defined(AFS_AMD64_LINUX26_ENV)
+static int check_writable(unsigned long address) 
+{ 
+    pgd_t *pgd = pgd_offset_k(address);
+#ifdef PUD_SIZE
+    pud_t *pud;
+#endif
+    pmd_t *pmd;
+    pte_t *pte;
+
+    if (pgd_none(*pgd))
+	return 0;
+#ifdef PUD_SIZE
+    pud = pud_offset(pgd, address);
+    if (pud_none(*pud))
+	return 0;
+    pmd = pmd_offset(pud, address);
+#else
+    pmd = pmd_offset(pgd, address);
+#endif
+    if (pmd_none(*pmd))
+	return 0;
+    if (pmd_large(*pmd))
+	pte = (pte_t *)pmd;
+    else
+	pte = pte_offset_kernel(pmd, address);
+    if (pte_none(*pte) || !pte_present(*pte) || !pte_write(*pte))
+	return 0;
+    return 1;
+}
+#endif
+
 void *osi_find_syscall_table(int which)
 {
     probectl *P;
@@ -1203,6 +1369,13 @@ void *osi_find_syscall_table(int which)
 	return 0;
     }
     printk("Found %s at 0x%lx (%s)\n", P->desc, (unsigned long)answer, method);
+#if defined(AFS_I386_LINUX26_ENV) || defined(AFS_AMD64_LINUX26_ENV)
+    if (!check_writable((unsigned long)answer)) {
+	printk("Address 0x%lx is not writable.\n", (unsigned long)answer);
+	printk("System call hooks will not be installed; proceeding anyway\n");
+	return 0;
+    }
+#endif
     return answer;
 }
 
