@@ -11,7 +11,7 @@
 #include "afs/param.h"
 
 RCSID
-    ("$Header: /cvs/openafs/src/afs/LINUX/osi_sleep.c,v 1.22.2.5 2005/08/02 14:04:47 shadow Exp $");
+    ("$Header: /cvs/openafs/src/afs/LINUX/osi_sleep.c,v 1.30 2005/09/19 03:39:13 shadow Exp $");
 
 #include "afs/sysincludes.h"	/* Standard vendor system headers */
 #include "afsincludes.h"	/* Afs-based standard headers */
@@ -194,8 +194,18 @@ afs_osi_SleepSig(void *event)
 	schedule();
 #ifdef AFS_LINUX26_ENV
 #ifdef CONFIG_PM
-	if (current->flags & PF_FREEZE)
+	if (
+#ifdef PF_FREEZE
+	    current->flags & PF_FREEZE
+#else
+	    !current->todo
+#endif
+	    )
+#ifdef LINUX_REFRIGERATOR_TAKES_PF_FREEZE
 	    refrigerator(PF_FREEZE);
+#else
+	    refrigerator();
+#endif
 #endif
 #endif
 	AFS_GLOCK();
@@ -278,8 +288,18 @@ osi_TimedSleep(char *event, afs_int32 ams, int aintok)
 	schedule_timeout(ticks);
 #ifdef AFS_LINUX26_ENV
 #ifdef CONFIG_PM
-    if (current->flags & PF_FREEZE)
+    if (
+#ifdef PF_FREEZE
+	    current->flags & PF_FREEZE
+#else
+	    !current->todo
+#endif
+	    )
+#ifdef LINUX_REFRIGERATOR_TAKES_PF_FREEZE
 	refrigerator(PF_FREEZE);
+#else
+	refrigerator();
+#endif
 #endif
 #endif
 
