@@ -16,7 +16,7 @@
 #include "afs/param.h"
 
 RCSID
-    ("$Header: /cvs/openafs/src/afs/LINUX/osi_vfsops.c,v 1.29.2.6 2005/07/11 19:29:56 shadow Exp $");
+    ("$Header: /cvs/openafs/src/afs/LINUX/osi_vfsops.c,v 1.42.4.1 2006/06/01 15:58:06 shadow Exp $");
 
 #define __NO_VERSION__		/* don't define kernel_version in module.h */
 #include <linux/module.h> /* early to avoid printf->printk mapping */
@@ -132,7 +132,18 @@ afs_read_super(struct super_block *sb, void *data, int silent)
     sb->s_magic = AFS_VFSMAGIC;
     sb->s_op = &afs_sops;	/* Super block (vfs) ops */
 #if defined(MAX_NON_LFS)
+#ifdef AFS_64BIT_CLIENT
+#if !defined(MAX_LFS_FILESIZE)
+#if BITS_PER_LONG==32
+#define MAX_LFS_FILESIZE (((u64)PAGE_CACHE_SIZE << (BITS_PER_LONG-1))-1) 
+#elif BITS_PER_LONG==64
+#define MAX_LFS_FILESIZE 0x7fffffffffffffff
+#endif
+#endif
+    sb->s_maxbytes = MAX_LFS_FILESIZE;
+#else
     sb->s_maxbytes = MAX_NON_LFS;
+#endif
 #endif
     code = afs_root(sb);
     if (code) {
@@ -313,7 +324,7 @@ afs_clear_inode(struct inode *ip)
 
     if (vcp->vlruq.prev || vcp->vlruq.next)
 	osi_Panic("inode freed while on LRU");
-    if (vcp->hnext || vcp->vhnext)
+    if (vcp->hnext)
 	osi_Panic("inode freed while still hashed");
 
 #if !defined(STRUCT_SUPER_HAS_ALLOC_INODE)
@@ -330,16 +341,12 @@ afs_clear_inode(struct inode *ip)
 static void
 afs_put_inode(struct inode *ip)
 {
-    cred_t *credp = crref();
     struct vcache *vcp = VTOAFS(ip);
 
     AFS_GLOCK();
-    ObtainReadLock(&vcp->lock);
-    if (VREFCOUNT(vcp) == 2)
-	afs_InactiveVCache(vcp, credp);
-    ReleaseReadLock(&vcp->lock);
+    if (VREFCOUNT(vcp) == 2) 
+	afs_InactiveVCache(vcp, NULL);
     AFS_GUNLOCK();
-    crfree(credp);
 }
 
 /* afs_put_super
@@ -347,8 +354,6 @@ afs_put_inode(struct inode *ip)
 static void
 afs_put_super(struct super_block *sbp)
 {
-    int code = 0;
-
     AFS_GLOCK();
     AFS_STATCNT(afs_unmount);
 
@@ -371,14 +376,12 @@ afs_put_super(struct super_block *sbp)
     osi_linux_verify_alloced_memory();
     AFS_GUNLOCK();
 
-    if (!code) {
-	sbp->s_dev = 0;
+    sbp->s_dev = 0;
 #if defined(AFS_LINUX26_ENV)
-	module_put(THIS_MODULE);
+    module_put(THIS_MODULE);
 #else
-	MOD_DEC_USE_COUNT;
+    MOD_DEC_USE_COUNT;
 #endif
-    }
 }
 
 
@@ -425,12 +428,6 @@ afs_statfs(struct super_block *sbp, struct statfs *__statp, int size)
     return 0;
 }
 
-void
-afs_umount_begin(struct super_block *sbp)
-{
-    afs_shuttingdown = 1;
-}
-
 struct super_operations afs_sops = {
 #if defined(STRUCT_SUPER_HAS_ALLOC_INODE)
   .alloc_inode =	afs_alloc_inode,
@@ -440,7 +437,6 @@ struct super_operations afs_sops = {
   .put_inode =		afs_put_inode,
   .put_super =		afs_put_super,
   .statfs =		afs_statfs,
-  .umount_begin =	afs_umount_begin
 #if !defined(AFS_LINUX24_ENV)
   .notify_change =	afs_notify_change,
 #endif
