@@ -22,7 +22,7 @@
 #include "afs/param.h"
 
 RCSID
-    ("$Header: /cvs/openafs/src/afs/LINUX/osi_vnodeops.c,v 1.81.2.77 2009/03/19 04:54:50 shadow Exp $");
+    ("$Header: /cvs/openafs/src/afs/LINUX/osi_vnodeops.c,v 1.126 2006/04/05 16:04:34 shadow Exp $");
 
 #include "afs/sysincludes.h"
 #include "afsincludes.h"
@@ -45,19 +45,11 @@ RCSID
 #define pageoff(pp) pp->offset
 #endif
 
-#ifndef MAX_ERRNO
-#define MAX_ERRNO 1000L
-#endif
-
 #if defined(AFS_LINUX26_ENV)
 #define UnlockPage(pp) unlock_page(pp)
-extern struct backing_dev_info afs_backing_dev_info;
 #endif
 
 extern struct vcache *afs_globalVp;
-extern int afs_notify_change(struct dentry *dp, struct iattr *iattrp);
-
-
 static ssize_t
 afs_linux_read(struct file *fp, char *buf, size_t count, loff_t * offp)
 {
@@ -81,11 +73,7 @@ afs_linux_read(struct file *fp, char *buf, size_t count, loff_t * offp)
     else {
 	    osi_FlushPages(vcp, credp);	/* ensure stale pages are gone */
 	    AFS_GUNLOCK();
-#ifdef DO_SYNC_READ
-	    code = do_sync_read(fp, buf, count, offp);
-#else
 	    code = generic_file_read(fp, buf, count, offp);
-#endif
 	    AFS_GLOCK();
     }
 
@@ -107,6 +95,7 @@ static ssize_t
 afs_linux_write(struct file *fp, const char *buf, size_t count, loff_t * offp)
 {
     ssize_t code = 0;
+    int code2 = 0;
     struct vcache *vcp = VTOAFS(fp->f_dentry->d_inode);
     struct vrequest treq;
     cred_t *credp = crref();
@@ -130,11 +119,7 @@ afs_linux_write(struct file *fp, const char *buf, size_t count, loff_t * offp)
 	code = -code;
     else {
 	    AFS_GUNLOCK();
-#ifdef DO_SYNC_READ
-	    code = do_sync_write(fp, buf, count, offp);
-#else
 	    code = generic_file_write(fp, buf, count, offp);
-#endif
 	    AFS_GLOCK();
     }
 
@@ -242,8 +227,8 @@ afs_linux_readdir(struct file *fp, void *dirbuf, filldir_t filldir)
 	if (!de)
 	    break;
 
-	ino = (avc->fid.Fid.Volume << 16) + ntohl(de->fid.vnode);
-	ino &= 0x7fffffff;	/* Assumes 32 bit ino_t ..... */
+	ino = afs_calc_inum (avc->fid.Fid.Volume, ntohl(de->fid.vnode));
+
 	if (de->name)
 	    len = strlen(de->name);
 	else {
@@ -477,22 +462,22 @@ afs_linux_lock(struct file *fp, int cmd, struct file_lock *flp)
     AFS_GUNLOCK();
 
 #ifdef AFS_LINUX24_ENV
-    if ((code == 0 || flp->fl_type == F_UNLCK) && 
-        (cmd == F_SETLK || cmd == F_SETLKW)) {
-#ifdef POSIX_LOCK_FILE_WAIT_ARG
-	code = posix_lock_file(fp, flp, 0);
-#else
-	flp->fl_flags &=~ FL_SLEEP;
-	code = posix_lock_file(fp, flp);
-#endif 
-	if (code && flp->fl_type != F_UNLCK) {
-	    struct AFS_FLOCK flock2;
-	    flock2 = flock;
-	    flock2.l_type = F_UNLCK;
-	    AFS_GLOCK();
-	    afs_lockctl(vcp, &flock2, F_SETLK, credp);
-	    AFS_GUNLOCK();
-	}
+    if (code == 0 && (cmd == F_SETLK || cmd == F_SETLKW)) {
+       struct file_lock flp2;
+       flp2 = *flp;
+#ifdef AFS_LINUX26_ENV
+       flp2.fl_flags &=~ FL_SLEEP;
+#endif
+       code = posix_lock_file(fp, &flp2);
+       osi_Assert(code != -EAGAIN); /* there should be no conflicts */
+       if (code) {
+           struct AFS_FLOCK flock2;
+           flock2 = flock;
+           flock2.l_type = F_UNLCK;
+           AFS_GLOCK();
+           afs_lockctl(vcp, &flock2, F_SETLK, credp);
+           AFS_GUNLOCK();
+       }
     }
 #endif
     /* Convert flock back to Linux's file_lock */
@@ -506,90 +491,27 @@ afs_linux_lock(struct file *fp, int cmd, struct file_lock *flp)
 
 }
 
-#ifdef STRUCT_FILE_OPERATIONS_HAS_FLOCK
-static int
-afs_linux_flock(struct file *fp, int cmd, struct file_lock *flp) {
-    int code = 0;
-    struct vcache *vcp = VTOAFS(FILE_INODE(fp));
-    cred_t *credp = crref();
-    struct AFS_FLOCK flock;
-    /* Convert to a lock format afs_lockctl understands. */
-    memset((char *)&flock, 0, sizeof(flock));
-    flock.l_type = flp->fl_type;
-    flock.l_pid = flp->fl_pid;
-    flock.l_whence = 0;
-    flock.l_start = 0;
-    flock.l_len = OFFSET_MAX;
-
-    /* Safe because there are no large files, yet */
-#if defined(F_GETLK64) && (F_GETLK != F_GETLK64)
-    if (cmd == F_GETLK64)
-	cmd = F_GETLK;
-    else if (cmd == F_SETLK64)
-	cmd = F_SETLK;
-    else if (cmd == F_SETLKW64)
-	cmd = F_SETLKW;
-#endif /* F_GETLK64 && F_GETLK != F_GETLK64 */
-
-    AFS_GLOCK();
-    code = afs_lockctl(vcp, &flock, cmd, credp);
-    AFS_GUNLOCK();
-
-    if ((code == 0 || flp->fl_type == F_UNLCK) && 
-        (cmd == F_SETLK || cmd == F_SETLKW)) {
-	flp->fl_flags &=~ FL_SLEEP;
-	code = flock_lock_file_wait(fp, flp);
-	if (code && flp->fl_type != F_UNLCK) {
-	    struct AFS_FLOCK flock2;
-	    flock2 = flock;
-	    flock2.l_type = F_UNLCK;
-	    AFS_GLOCK();
-	    afs_lockctl(vcp, &flock2, F_SETLK, credp);
-	    AFS_GUNLOCK();
-	}
-    }
-    /* Convert flock back to Linux's file_lock */
-    flp->fl_type = flock.l_type;
-    flp->fl_pid = flock.l_pid;
-
-    crfree(credp);
-    return -code;
-}
-#endif
-
 /* afs_linux_flush
  * essentially the same as afs_fsync() but we need to get the return
  * code for the sys_close() here, not afs_linux_release(), so call
  * afs_StoreAllSegments() with AFS_LASTSTORE
  */
 static int
-#if defined(FOP_FLUSH_TAKES_FL_OWNER_T)
-afs_linux_flush(struct file *fp, fl_owner_t id)
-#else
 afs_linux_flush(struct file *fp)
-#endif
 {
     struct vrequest treq;
-    struct vcache *vcp;
-    cred_t *credp;
+    struct vcache *vcp = VTOAFS(FILE_INODE(fp));
+    cred_t *credp = crref();
     int code;
 
     AFS_GLOCK();
 
-    if ((fp->f_flags & O_ACCMODE) == O_RDONLY) { /* readers dont flush */
-	AFS_GUNLOCK();
-	return 0;
-    }
-
-    credp = crref();
-    vcp = VTOAFS(FILE_INODE(fp));
-
     code = afs_InitReq(&treq, credp);
     if (code)
 	goto out;
 
     ObtainSharedLock(&vcp->lock, 535);
-    if ((vcp->execsOrWriters > 0) && (file_count(fp) == 1)) {
+    if (vcp->execsOrWriters > 0) {
 	UpgradeSToWLock(&vcp->lock, 536);
 	code = afs_StoreAllSegments(vcp, &treq, AFS_SYNC | AFS_LASTSTORE);
 	ConvertWToSLock(&vcp->lock);
@@ -639,10 +561,6 @@ struct file_operations afs_dir_fops = {
 struct file_operations afs_file_fops = {
   .read =	afs_linux_read,
   .write =	afs_linux_write,
-#ifdef GENERIC_FILE_AIO_READ
-  .aio_read =	generic_file_aio_read,
-  .aio_write =	generic_file_aio_write,
-#endif
 #ifdef HAVE_UNLOCKED_IOCTL
   .unlocked_ioctl = afs_unlocked_xioctl,
 #else
@@ -654,19 +572,12 @@ struct file_operations afs_file_fops = {
   .mmap =	afs_linux_mmap,
   .open =	afs_linux_open,
   .flush =	afs_linux_flush,
-#if defined(AFS_LINUX26_ENV) && defined(STRUCT_FILE_OPERATIONS_HAS_SENDFILE)
+#ifdef AFS_LINUX26_ENV
   .sendfile =   generic_file_sendfile,
-#endif
-#if defined(AFS_LINUX26_ENV) && defined(STRUCT_FILE_OPERATIONS_HAS_SPLICE)
-  .splice_write = generic_file_splice_write,
-  .splice_read = generic_file_splice_read,
 #endif
   .release =	afs_linux_release,
   .fsync =	afs_linux_fsync,
   .lock =	afs_linux_lock,
-#ifdef STRUCT_FILE_OPERATIONS_HAS_FLOCK
-  .flock =	afs_linux_flock,
-#endif
 };
 
 
@@ -750,7 +661,7 @@ afs_linux_revalidate(struct dentry *dp)
     credp = crref();
     code = afs_getattr(vcp, &vattr, credp);
     if (!code)
-        afs_fill_inode(AFSTOV(vcp), &vattr);
+        vattr2inode(AFSTOV(vcp), &vattr);
 
     AFS_GUNLOCK();
 #ifdef AFS_LINUX24_ENV
@@ -795,13 +706,11 @@ afs_linux_dentry_revalidate(struct dentry *dp)
     cred_t *credp = NULL;
     struct vcache *vcp, *pvcp, *tvc = NULL;
     int valid;
-    struct afs_fakestat_state fakestate;
 
 #ifdef AFS_LINUX24_ENV
     lock_kernel();
 #endif
     AFS_GLOCK();
-    afs_InitFakeStat(&fakestate);
 
     if (dp->d_inode) {
 
@@ -811,34 +720,8 @@ afs_linux_dentry_revalidate(struct dentry *dp)
 	if (vcp == afs_globalVp)
 	    goto good_dentry;
 
-	if (vcp->mvstat == 1) {         /* mount point */
-	    if (vcp->mvid && (vcp->states & CMValid)) {
-		int tryEvalOnly = 0;
-		int code = 0;
-		struct vrequest treq;
-
-		credp = crref();
-		code = afs_InitReq(&treq, credp);
-		if (
-#ifdef AFS_DARWIN_ENV
-		    (strcmp(dp->d_name.name, ".DS_Store") == 0) ||
-		    (strcmp(dp->d_name.name, "Contents") == 0) ||
-#endif
-		    (strcmp(dp->d_name.name, ".directory") == 0)) {
-		    tryEvalOnly = 1;
-		}
-		if (tryEvalOnly)
-		    code = afs_TryEvalFakeStat(&vcp, &fakestate, &treq);
-		else
-		    code = afs_EvalFakeStat(&vcp, &fakestate, &treq);
-		if ((tryEvalOnly && vcp->mvstat == 1) || code) {
-		    /* a mount point, not yet replaced by its directory */
-		    goto bad_dentry;
-		}
-	    }
-	} else
-	    if (*dp->d_name.name != '/' && vcp->mvstat == 2) /* root vnode */
-		check_bad_parent(dp);	/* check and correct mvid */
+	if (*dp->d_name.name != '/' && vcp->mvstat == 2)	/* root vnode */
+	    check_bad_parent(dp);	/* check and correct mvid */
 
 #ifdef notdef
 	/* If the last looker changes, we should make sure the current
@@ -898,7 +781,6 @@ afs_linux_dentry_revalidate(struct dentry *dp)
     /* Clean up */
     if (tvc)
 	afs_PutVCache(tvc);
-    afs_PutFakeStat(&fakestate);
     AFS_GUNLOCK();
     if (credp)
 	crfree(credp);
@@ -913,10 +795,7 @@ afs_linux_dentry_revalidate(struct dentry *dp)
     return valid;
 
   bad_dentry:
-    if (have_submounts(dp))
-	valid = 1;
-    else 
-	valid = 0;
+    valid = 0;
     goto done;
 }
 
@@ -926,17 +805,9 @@ afs_dentry_iput(struct dentry *dp, struct inode *ip)
     struct vcache *vcp = VTOAFS(ip);
 
     AFS_GLOCK();
-    (void) afs_InactiveVCache(vcp, NULL);
+    if (vcp->states & CUnlinked)
+	(void) afs_InactiveVCache(vcp, NULL);
     AFS_GUNLOCK();
-#ifdef DCACHE_NFSFS_RENAMED
-#ifdef AFS_LINUX26_ENV
-    spin_lock(&dp->d_lock);
-#endif
-    dp->d_flags &= ~DCACHE_NFSFS_RENAMED;   
-#ifdef AFS_LINUX26_ENV
-    spin_unlock(&dp->d_lock);
-#endif
-#endif
 
     iput(ip);
 }
@@ -998,7 +869,6 @@ afs_linux_create(struct inode *dip, struct dentry *dp, int mode)
 
 	afs_getattr(vcp, &vattr, credp);
 	afs_fill_inode(ip, &vattr);
-	insert_inode_hash(ip);
 	dp->d_op = &afs_dentry_operations;
 	dp->d_time = hgetlo(VTOAFS(dip)->m.DataVersion);
 	d_instantiate(dp, ip);
@@ -1044,16 +914,6 @@ afs_linux_lookup(struct inode *dip, struct dentry *dp)
 	ip = AFSTOV(vcp);
 	afs_getattr(vcp, &vattr, credp);
 	afs_fill_inode(ip, &vattr);
-	if (
-#ifdef HAVE_KERNEL_HLIST_UNHASHED
-	    hlist_unhashed(&ip->i_hash)
-#elif defined(AFS_LINUX26_ENV)
-	    ip->i_hash.pprev == NULL
-#else
-	    ip->i_hash.prev == NULL
-#endif
-	    )
-	    insert_inode_hash(ip);
     }
     dp->d_op = &afs_dentry_operations;
     dp->d_time = hgetlo(VTOAFS(dip)->m.DataVersion);
@@ -1072,7 +932,6 @@ afs_linux_lookup(struct inode *dip, struct dentry *dp)
 #if defined(AFS_LINUX26_ENV)
 		unlock_kernel();
 #endif
-		crfree(credp);
 		return alias;
 	    }
 	}
@@ -1091,10 +950,8 @@ afs_linux_lookup(struct inode *dip, struct dentry *dp)
 #if LINUX_VERSION_CODE >= KERNEL_VERSION(2,2,10)
     if (code == ENOENT)
 	return ERR_PTR(0);
-    else if ((code >= 0) && (code <= MAX_ERRNO))
+    else
 	return ERR_PTR(-code);
-    else 
-	return ERR_PTR(-EIO);
 #else
     if (code == ENOENT)
 	code = 0;
@@ -1167,17 +1024,6 @@ afs_linux_unlink(struct inode *dip, struct dentry *dp)
             }
             tvc->uncred = credp;
 	    tvc->states |= CUnlinked;
-#ifdef DCACHE_NFSFS_RENAMED
-#ifdef AFS_LINUX26_ENV
-	    spin_lock(&dp->d_lock);
-#endif
-	    dp->d_flags |= DCACHE_NFSFS_RENAMED;   
-#ifdef AFS_LINUX26_ENV
-	    spin_unlock(&dp->d_lock);
-#endif
-#endif
-	} else {
-	    osi_FreeSmallSpace(__name);	
 	}
 	AFS_GUNLOCK();
 
@@ -1305,7 +1151,13 @@ afs_linux_rename(struct inode *oldip, struct dentry *olddp,
 #if defined(AFS_LINUX26_ENV)
     /* Prevent any new references during rename operation. */
     lock_kernel();
-
+#endif
+    /* Remove old and new entries from name hash. New one will change below.
+     * While it's optimal to catch failures and re-insert newdp into hash,
+     * it's also error prone and in that case we're already dealing with error
+     * cases. Let another lookup put things right, if need be.
+     */
+#if defined(AFS_LINUX26_ENV)
     if (!d_unhashed(newdp)) {
 	d_drop(newdp);
 	rehash = newdp;
@@ -1326,9 +1178,6 @@ afs_linux_rename(struct inode *oldip, struct dentry *olddp,
     code = afs_rename(VTOAFS(oldip), oldname, VTOAFS(newip), newname, credp);
     AFS_GUNLOCK();
 
-    if (!code)
-	olddp->d_time = 0;      /* force to revalidate */
-
     if (rehash)
 	d_rehash(rehash);
 
@@ -1363,7 +1212,7 @@ afs_linux_ireadlink(struct inode *ip, char *target, int maxlen, uio_seg_t seg)
 	return -code;
 }
 
-#if !defined(USABLE_KERNEL_PAGE_SYMLINK_CACHE)
+#if !defined(AFS_LINUX24_ENV)
 /* afs_linux_readlink 
  * Fill target (which is in user space) with contents of symlink.
  */
@@ -1383,36 +1232,6 @@ afs_linux_readlink(struct dentry *dp, char *target, int maxlen)
 /* afs_linux_follow_link
  * a file system dependent link following routine.
  */
-#if defined(AFS_LINUX24_ENV)
-static int afs_linux_follow_link(struct dentry *dentry, struct nameidata *nd)
-{
-    int code;
-    char *name;
-
-    name = osi_Alloc(PATH_MAX);
-    if (!name) {
-	return -EIO;
-    }
-
-    AFS_GLOCK();
-    code = afs_linux_ireadlink(dentry->d_inode, name, PATH_MAX - 1, AFS_UIOSYS);
-    AFS_GUNLOCK();
-
-    if (code < 0) {
-	goto out;
-    }
-
-    name[code] = '\0';
-    code = vfs_follow_link(nd, name);
-
-out:
-    osi_Free(name, PATH_MAX);
-
-    return code;
-}
-
-#else /* !defined(AFS_LINUX24_ENV) */
-
 static struct dentry *
 afs_linux_follow_link(struct dentry *dp, struct dentry *basep,
 		      unsigned int follow)
@@ -1435,10 +1254,7 @@ afs_linux_follow_link(struct dentry *dp, struct dentry *basep,
 
     if (code < 0) {
 	dput(basep);
-	if (code < -MAX_ERRNO)
-	    res = ERR_PTR(-EIO);
-	else
-	    res = ERR_PTR(code);
+	res = ERR_PTR(code);
     } else {
 	name[code] = '\0';
 	res = lookup_dentry(name, basep, follow);
@@ -1449,8 +1265,7 @@ afs_linux_follow_link(struct dentry *dp, struct dentry *basep,
     AFS_GUNLOCK();
     return res;
 }
-#endif /* AFS_LINUX24_ENV */
-#endif /* USABLE_KERNEL_PAGE_SYMLINK_CACHE */
+#endif
 
 /* afs_linux_readpage
  * all reads come through here. A strategy-like read call.
@@ -1483,7 +1298,7 @@ afs_linux_readpage(struct file *fp, struct page *pp)
     clear_bit(PG_error, &pp->flags);
 #endif
 
-    setup_uio(&tuio, &iovec, (char *)address, offset, PAGE_SIZE, UIO_READ,
+    setup_uio(&tuio, &iovec, (char *)address, offset, PAGESIZE, UIO_READ,
 	      AFS_UIOSYS);
 #ifdef AFS_LINUX24_ENV
     lock_kernel();
@@ -1501,7 +1316,7 @@ afs_linux_readpage(struct file *fp, struct page *pp)
 
     if (!code) {
 	if (tuio.uio_resid)	/* zero remainder of page */
-	    memset((void *)(address + (PAGE_SIZE - tuio.uio_resid)), 0,
+	    memset((void *)(address + (PAGESIZE - tuio.uio_resid)), 0,
 		   tuio.uio_resid);
 #if LINUX_VERSION_CODE >= KERNEL_VERSION(2,4,0)
 	flush_dcache_page(pp);
@@ -1567,31 +1382,11 @@ afs_linux_writepage_sync(struct inode *ip, struct page *pp,
 	       ICL_TYPE_POINTER, pp, ICL_TYPE_INT32, page_count(pp),
 	       ICL_TYPE_INT32, 99999);
 
-    ObtainReadLock(&vcp->lock);
-    if (vcp->states & CPageWrite) {
-	ReleaseReadLock(&vcp->lock);
-	AFS_GUNLOCK();
-	unlock_kernel();
-	crfree(credp);
-	kunmap(pp);
-#ifdef AFS_LINUX26_ENV
-#if defined(WRITEPAGE_ACTIVATE)
-	return WRITEPAGE_ACTIVATE;
-#else
-	return AOP_WRITEPAGE_ACTIVATE;
-#endif
-#else
-	/* should mark it dirty? */
-	return(0); 
-#endif
-    }
-    ReleaseReadLock(&vcp->lock);
-
     setup_uio(&tuio, &iovec, buffer, base, count, UIO_WRITE, AFS_UIOSYS);
 
     code = afs_write(vcp, &tuio, f_flags, credp, 0);
 
-    i_size_write(ip, vcp->m.Length);
+    ip->i_size = vcp->m.Length;
     ip->i_blocks = ((vcp->m.Length + 1023) >> 10) << 1;
 
     if (!code) {
@@ -1645,13 +1440,13 @@ afs_linux_writepage(struct page *pp)
 #endif
 
     inode = (struct inode *)mapping->host;
-    end_index = i_size_read(inode) >> PAGE_CACHE_SHIFT;
+    end_index = inode->i_size >> PAGE_CACHE_SHIFT;
 
     /* easy case */
     if (pp->index < end_index)
 	goto do_it;
     /* things got complicated... */
-    offset = i_size_read(inode) & (PAGE_CACHE_SIZE - 1);
+    offset = inode->i_size & (PAGE_CACHE_SIZE - 1);
     /* OK, are we completely out? */
     if (pp->index >= end_index + 1 || !offset)
 	return -EIO;
@@ -1694,7 +1489,7 @@ afs_linux_updatepage(struct file *fp, struct page *pp, unsigned long offset,
 
     code = afs_write(vcp, &tuio, fp->f_flags, credp, 0);
 
-    i_size_write(ip, vcp->m.Length);
+    ip->i_size = vcp->m.Length;
     ip->i_blocks = ((vcp->m.Length + 1023) >> 10) << 1;
 
     if (!code) {
@@ -1748,7 +1543,7 @@ afs_linux_permission(struct inode *ip, int mode)
     return -code;
 }
 
-#if defined(AFS_LINUX24_ENV) && !(LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,28) && defined(HAVE_WRITE_BEGIN))
+#if defined(AFS_LINUX24_ENV)
 static int
 afs_linux_commit_write(struct file *file, struct page *page, unsigned offset,
 		       unsigned to)
@@ -1775,41 +1570,8 @@ afs_linux_prepare_write(struct file *file, struct page *page, unsigned from,
 #endif
     return 0;
 }
-#endif
 
-#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,28) && defined(HAVE_WRITE_BEGIN)
-static int
-afs_linux_write_end(struct file *file, struct address_space *mapping,
-                                loff_t pos, unsigned len, unsigned copied,
-                                struct page *page, void *fsdata)
-{
-    int code;
-    pgoff_t index = pos >> PAGE_CACHE_SHIFT;
-    unsigned from = pos & (PAGE_CACHE_SIZE - 1);
-
-    code = afs_linux_writepage_sync(file->f_dentry->d_inode, page,
-                                    from, copied);
-    unlock_page(page);
-    page_cache_release(page);
-    return code;
-}
-
-static int
-afs_linux_write_begin(struct file *file, struct address_space *mapping,
-                                loff_t pos, unsigned len, unsigned flags,
-                                struct page **pagep, void **fsdata)
-{
-    struct page *page;
-    pgoff_t index = pos >> PAGE_CACHE_SHIFT;
-#if defined(HAVE_GRAB_CACHE_PAGE_WRITE_BEGIN)
-    page = grab_cache_page_write_begin(mapping, index, flags);
-#else
-    page = __grab_cache_page(mapping, index);
-#endif
-    *pagep = page;
-
-    return 0;
-}
+extern int afs_notify_change(struct dentry *dp, struct iattr *iattrp);
 #endif
 
 static struct inode_operations afs_file_iops = {
@@ -1833,13 +1595,8 @@ static struct inode_operations afs_file_iops = {
 static struct address_space_operations afs_file_aops = {
   .readpage =		afs_linux_readpage,
   .writepage =		afs_linux_writepage,
-#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,28) && defined(HAVE_WRITE_BEGIN)
-  .write_begin =        afs_linux_write_begin,
-  .write_end =          afs_linux_write_end,
-#else
-  .commit_write =       afs_linux_commit_write,
-  .prepare_write =      afs_linux_prepare_write,
-#endif
+  .commit_write =	afs_linux_commit_write,
+  .prepare_write =	afs_linux_prepare_write,
 };
 #endif
 
@@ -1873,7 +1630,7 @@ static struct inode_operations afs_dir_iops = {
 /* We really need a separate symlink set of ops, since do_follow_link()
  * determines if it _is_ a link by checking if the follow_link op is set.
  */
-#if defined(USABLE_KERNEL_PAGE_SYMLINK_CACHE)
+#if defined(AFS_LINUX24_ENV)
 static int
 afs_symlink_filler(struct file *file, struct page *page)
 {
@@ -1908,10 +1665,10 @@ afs_symlink_filler(struct file *file, struct page *page)
 static struct address_space_operations afs_symlink_aops = {
   .readpage =	afs_symlink_filler
 };
-#endif	/* USABLE_KERNEL_PAGE_SYMLINK_CACHE */
+#endif
 
 static struct inode_operations afs_symlink_iops = {
-#if defined(USABLE_KERNEL_PAGE_SYMLINK_CACHE)
+#if defined(AFS_LINUX24_ENV)
   .readlink = 		page_readlink,
 #if defined(HAVE_KERNEL_PAGE_FOLLOW_LINK)
   .follow_link =	page_follow_link,
@@ -1919,17 +1676,13 @@ static struct inode_operations afs_symlink_iops = {
   .follow_link =	page_follow_link_light,
   .put_link =           page_put_link,
 #endif
-#else /* !defined(USABLE_KERNEL_PAGE_SYMLINK_CACHE) */
+  .setattr =		afs_notify_change,
+#else
   .readlink = 		afs_linux_readlink,
   .follow_link =	afs_linux_follow_link,
-#if !defined(AFS_LINUX24_ENV)
   .permission =		afs_linux_permission,
   .revalidate =		afs_linux_revalidate,
 #endif
-#endif /* USABLE_KERNEL_PAGE_SYMLINK_CACHE */
-#if defined(AFS_LINUX24_ENV)
-  .setattr =		afs_notify_change,
-#endif
 };
 
 void
@@ -1939,9 +1692,6 @@ afs_fill_inode(struct inode *ip, struct vattr *vattr)
     if (vattr)
 	vattr2inode(ip, vattr);
 
-#if defined(AFS_LINUX26_ENV)
-    ip->i_mapping->backing_dev_info = &afs_backing_dev_info;
-#endif
 /* Reset ops if symlink or directory. */
     if (S_ISREG(ip->i_mode)) {
 	ip->i_op = &afs_file_iops;
@@ -1958,10 +1708,11 @@ afs_fill_inode(struct inode *ip, struct vattr *vattr)
 
     } else if (S_ISLNK(ip->i_mode)) {
 	ip->i_op = &afs_symlink_iops;
-#if defined(USABLE_KERNEL_PAGE_SYMLINK_CACHE)
+#if defined(AFS_LINUX24_ENV)
 	ip->i_data.a_ops = &afs_symlink_aops;
 	ip->i_mapping = &ip->i_data;
 #endif
     }
 
+    /* insert_inode_hash(ip);	-- this would make iget() work (if we used it) */
 }
