@@ -15,7 +15,7 @@
 #include "afs/param.h"
 
 RCSID
-    ("$Header: /cvs/openafs/src/afs/UKERNEL/afs_usrops.c,v 1.27.2.1 2004/08/25 07:15:34 shadow Exp $");
+    ("$Header: /cvs/openafs/src/afs/UKERNEL/afs_usrops.c,v 1.30 2005/04/14 02:25:12 shadow Exp $");
 
 
 #ifdef	UKERNEL
@@ -459,16 +459,12 @@ afs_osi_Sleep(void *x)
 {
     int index;
     osi_wait_t *waitp;
-    int rxGlockOwner = ISAFS_RXGLOCK();
     int glockOwner = ISAFS_GLOCK();
 
     usr_mutex_lock(&osi_waitq_lock);
     if (glockOwner) {
 	AFS_GUNLOCK();
     }
-    if (rxGlockOwner) {
-	AFS_RXGUNLOCK();
-    }
     index = WAITHASH(x);
     if (osi_waithash_avail == NULL) {
 	waitp = (osi_wait_t *) afs_osi_Alloc(sizeof(osi_wait_t));
@@ -495,9 +491,6 @@ afs_osi_Sleep(void *x)
     if (glockOwner) {
 	AFS_GLOCK();
     }
-    if (rxGlockOwner) {
-	AFS_RXGLOCK();
-    }
 }
 
 int
@@ -533,7 +526,6 @@ afs_osi_Wait(afs_int32 msec, struct afs_osi_WaitHandle *handle, int intok)
     osi_wait_t *waitp;
     struct timespec tv;
     int ret;
-    int rxGlockOwner = ISAFS_RXGLOCK();
     int glockOwner = ISAFS_GLOCK();
 
     tv.tv_sec = msec / 1000;
@@ -542,25 +534,16 @@ afs_osi_Wait(afs_int32 msec, struct afs_osi_WaitHandle *handle, int intok)
 	if (glockOwner) {
 	    AFS_GUNLOCK();
 	}
-	if (rxGlockOwner) {
-	    AFS_RXGUNLOCK();
-	}
 	usr_thread_sleep(&tv);
 	ret = 0;
 	if (glockOwner) {
 	    AFS_GLOCK();
 	}
-	if (rxGlockOwner) {
-	    AFS_RXGLOCK();
-	}
     } else {
 	usr_mutex_lock(&osi_waitq_lock);
 	if (glockOwner) {
 	    AFS_GUNLOCK();
 	}
-	if (rxGlockOwner) {
-	    AFS_RXGUNLOCK();
-	}
 	index = WAITHASH((caddr_t) handle);
 	if (osi_waithash_avail == NULL) {
 	    waitp = (osi_wait_t *) afs_osi_Alloc(sizeof(osi_wait_t));
@@ -593,9 +576,6 @@ afs_osi_Wait(afs_int32 msec, struct afs_osi_WaitHandle *handle, int intok)
 	if (glockOwner) {
 	    AFS_GLOCK();
 	}
-	if (rxGlockOwner) {
-	    AFS_RXGLOCK();
-	}
     }
     return ret;
 }
@@ -650,7 +630,7 @@ int max_osi_files = 0;
  */
 int
 lookupname(char *fnamep, int segflg, int followlink,
-	   struct usr_vnode **dirvpp, struct usr_vnode **compvpp)
+	   struct usr_vnode **compvpp)
 {
     int i;
     int code;
@@ -658,7 +638,6 @@ lookupname(char *fnamep, int segflg, int followlink,
     struct usr_vnode *vp;
 
     /*usr_assert(followlink == 0); */
-    usr_assert(dirvpp == NULL);
 
     /*
      * Assume relative pathnames refer to files in AFS
