@@ -11,7 +11,7 @@
 #include "afs/param.h"
 
 RCSID
-    ("$Header: /cvs/openafs/src/afs/afs_osi.c,v 1.48.2.20 2009/03/27 15:55:43 shadow Exp $");
+    ("$Header: /cvs/openafs/src/afs/afs_osi.c,v 1.58 2006/02/15 20:53:02 shadow Exp $");
 
 #include "afs/sysincludes.h"	/* Standard vendor system headers */
 #include "afsincludes.h"	/* Afs-based standard headers */
@@ -58,11 +58,6 @@ osi_Init(void)
     usimple_lock_init(&afs_global_lock);
     afs_global_owner = (thread_t) 0;
 #elif defined(AFS_FBSD50_ENV)
-#if defined(AFS_FBSD80_ENV) && defined(WITNESS)
-    /* "lock_initalized" (sic) can panic, checks a flag bit
-     * is unset _before_ init */
-    memset(&afs_global_mtx, 0, sizeof(struct mtx));
-#endif
     mtx_init(&afs_global_mtx, "AFS global lock", NULL, MTX_DEF);
 #elif defined(AFS_DARWIN_ENV) || defined(AFS_XBSD_ENV)
 #if !defined(AFS_DARWIN80_ENV)
@@ -139,7 +134,6 @@ osi_Active(register struct vcache *avc)
 void
 osi_FlushPages(register struct vcache *avc, struct AFS_UCRED *credp)
 {
-    int vfslocked;
     afs_hyper_t origDV;
     ObtainReadLock(&avc->lock);
     /* If we've already purged this version, or if we're the ones
@@ -170,19 +164,9 @@ osi_FlushPages(register struct vcache *avc, struct AFS_UCRED *credp)
 	       ICL_TYPE_INT32, origDV.low, ICL_TYPE_INT32, avc->m.Length);
 
     ReleaseWriteLock(&avc->lock);
-#ifdef AFS_FBSD70_ENV
-    vfslocked = VFS_LOCK_GIANT(AFSTOV(avc)->v_mount);
-#endif
-#ifndef AFS_FBSD70_ENV
     AFS_GUNLOCK();
-#endif
     osi_VM_FlushPages(avc, credp);
-#ifndef AFS_FBSD70_ENV
     AFS_GLOCK();
-#endif
-#ifdef AFS_FBSD70_ENV
-    VFS_UNLOCK_GIANT(vfslocked);
-#endif
     ObtainWriteLock(&avc->lock, 88);
 
     /* do this last, and to original version, since stores may occur
@@ -296,6 +280,9 @@ afs_osi_UnmaskUserLoop()
 void
 afs_osi_RxkRegister(void)
 {
+#ifdef AFS_LINUX22_ENV
+    osi_linux_rxkreg();
+#endif
 }
 
 /* procedure for making our processes as invisible as we can */
@@ -321,21 +308,8 @@ afs_osi_Invisible(void)
     AFS_STATCNT(osi_Invisible);
 }
 
-void
-afs_osi_Visible(void)
-{
-#if defined(AFS_SUN5_ENV)
-    curproc->p_flag &= ~SSYS;
-#elif defined(AFS_DARWIN80_ENV)
-#elif defined(AFS_DARWIN_ENV)
-    /* maybe call init_process instead? */
-    current_proc()->p_flag &= ~P_SYSTEM;
-#elif defined(AFS_XBSD_ENV)
-    curproc->p_flag &= ~P_SYSTEM;
-#endif
-}
 
-#if !defined(AFS_LINUX20_ENV) && !defined(AFS_XBSD_ENV)
+#if !defined(AFS_LINUX20_ENV) && !defined(AFS_FBSD_ENV)
 /* set the real time */
 void
 afs_osi_SetTime(osi_timeval_t * atv)
@@ -435,8 +409,6 @@ afs_osi_Alloc(size_t x)
     return osi_linux_alloc(x, 1);
 #elif defined(AFS_FBSD_ENV)
     return osi_fbsd_alloc(x, 1);
-#elif defined(AFS_OBSD_ENV)
-    return osi_obsd_Alloc(x, 1);
 #else
     size = x;
     tm = (struct osimem *)AFS_KALLOC(size);
@@ -617,12 +589,10 @@ shutdown_osi(void)
 
 #ifndef AFS_OBSD_ENV
 int
-afs_osi_suser(void *cr)
+afs_osi_suser(void *credp)
 {
-#if defined(AFS_SUN510_ENV)
-    return (priv_policy(cr, PRIV_SYS_SUSER_COMPAT, B_FALSE, EPERM, NULL) == 0);
-#elif defined(AFS_SUN5_ENV)
-    return afs_suser(cr);
+#if defined(AFS_SUN5_ENV)
+    return afs_suser(credp);
 #else
     return afs_suser(NULL);
 #endif
@@ -835,26 +805,13 @@ afs_osi_TraverseProcTable(void)
 #endif
 
 #if defined(AFS_LINUX22_ENV)
-#ifdef EXPORTED_TASKLIST_LOCK
 extern rwlock_t tasklist_lock __attribute__((weak));
-#endif
 void
 afs_osi_TraverseProcTable()
 {
-#if !defined(LINUX_KEYRING_SUPPORT)
     struct task_struct *p;
-
-#if LINUX_VERSION_CODE < KERNEL_VERSION(2,6,18) && defined(EXPORTED_TASKLIST_LOCK)
     if (&tasklist_lock)
-	read_lock(&tasklist_lock);
-#endif /* EXPORTED_TASKLIST_LOCK */
-#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,16) 
-#if LINUX_VERSION_CODE < KERNEL_VERSION(2,6,18) && defined(EXPORTED_TASKLIST_LOCK)
-    else
-#endif /* EXPORTED_TASKLIST_LOCK && LINUX_VERSION_CODE < KERNEL_VERSION(2,6,18) */
-	rcu_read_lock();
-#endif /* LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,16) */
-
+       read_lock(&tasklist_lock);
 #ifdef DEFINED_FOR_EACH_PROCESS
     for_each_process(p) if (p->pid) {
 #ifdef STRUCT_TASK_STRUCT_HAS_EXIT_STATE
@@ -878,17 +835,8 @@ afs_osi_TraverseProcTable()
 	afs_GCPAGs_perproc_func(p);
     }
 #endif
-#if LINUX_VERSION_CODE < KERNEL_VERSION(2,6,18) && defined(EXPORTED_TASKLIST_LOCK)
     if (&tasklist_lock)
-	read_unlock(&tasklist_lock);
-#endif /* EXPORTED_TASKLIST_LOCK */
-#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,16) 
-#if LINUX_VERSION_CODE < KERNEL_VERSION(2,6,18) && defined(EXPORTED_TASKLIST_LOCK)
-    else
-#endif /* EXPORTED_TASKLIST_LOCK && LINUX_VERSION_CODE < KERNEL_VERSION(2,6,18) */
-	rcu_read_unlock();
-#endif /* LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,16) */
-#endif
+       read_unlock(&tasklist_lock);
 }
 #endif
 
@@ -1122,15 +1070,10 @@ afs_osi_proc2cred(AFS_PROC * pr)
 	|| (pr->state == TASK_UNINTERRUPTIBLE)
 	|| (pr->state == TASK_STOPPED)) {
 	cr.cr_ref = 1;
-	cr.cr_uid = task_uid(pr);
+	cr.cr_uid = pr->uid;
 #if defined(AFS_LINUX26_ENV)
-#if defined(STRUCT_TASK_HAS_CRED)
-	get_group_info(pr->cred->group_info);
-	cr.cr_group_info = pr->cred->group_info;
-#else
 	get_group_info(pr->group_info);
 	cr.cr_group_info = pr->group_info;
-#endif
 #else
 	cr.cr_ngroups = pr->ngroups;
 	memcpy(cr.cr_groups, pr->groups, NGROUPS * sizeof(gid_t));
