@@ -11,7 +11,7 @@
 #include <afs/param.h>
 
 RCSID
-    ("$Header: /cvs/openafs/src/auth/cellconfig.c,v 1.40.2.1 2004/08/25 07:09:36 shadow Exp $");
+    ("$Header: /cvs/openafs/src/auth/cellconfig.c,v 1.47 2006/03/28 18:39:45 shadow Exp $");
 
 #include <afs/stds.h>
 #include <afs/pthread_glock.h>
@@ -122,7 +122,7 @@ afsconf_FindService(register const char *aname)
     struct servent *ts;
     register struct afsconf_servPair *tsp;
 
-#if     defined(AFS_OSF_ENV) || defined(AFS_DEC_ENV)
+#if     defined(AFS_OSF_ENV) 
     ts = getservbyname(aname, "");
 #else
     ts = getservbyname(aname, NULL);
@@ -218,7 +218,7 @@ afsconf_Check(register struct afsconf_dir *adir)
 	} else {
 	    int len;
 	    strncpy(tbuffer, adir->name, sizeof(tbuffer));
-	    len = strlen(tbuffer);
+	    len = (int)strlen(tbuffer);
 	    if (tbuffer[len - 1] != '\\' && tbuffer[len - 1] != '/') {
 		strncat(tbuffer, "\\", sizeof(tbuffer));
 	    }
@@ -266,7 +266,7 @@ afsconf_Touch(register struct afsconf_dir *adir)
 		       AFSDIR_CELLSERVDB_FILE_NTCLIENT, NULL);
 	    free(p);
 	} else {
-	    int len = strlen(tbuffer);
+	    int len = (int)strlen(tbuffer);
 	    if (tbuffer[len - 1] != '\\' && tbuffer[len - 1] != '/') {
 		strncat(tbuffer, "\\", sizeof(tbuffer));
 	    }
@@ -449,7 +449,7 @@ afsconf_OpenInternal(register struct afsconf_dir *adir, char *cell,
 	} else {
 	    int len;
 	    strncpy(tbuffer, adir->name, sizeof(tbuffer));
-	    len = strlen(tbuffer);
+	    len = (int)strlen(tbuffer);
 	    if (tbuffer[len - 1] != '\\' && tbuffer[len - 1] != '/') {
 		strncat(tbuffer, "\\", sizeof(tbuffer));
 	    }
@@ -736,10 +736,11 @@ afsconf_GetAfsdbInfo(char *acellName, char *aservice,
 		     struct afsconf_cell *acellInfo)
 {
     afs_int32 code;
-    int tservice, i;
-    size_t len;
+    int tservice, i, len;
     unsigned char answer[1024];
     unsigned char *p;
+    char *dotcellname;
+    int cellnamelength;
     char realCellName[256];
     char host[256];
     int server_num = 0;
@@ -749,9 +750,25 @@ afsconf_GetAfsdbInfo(char *acellName, char *aservice,
      * replaced with a more fine-grained lock just for the resolver
      * operations.
      */
-    LOCK_GLOBAL_MUTEX;
-    len = res_search(acellName, C_IN, T_AFSDB, answer, sizeof(answer));
-    UNLOCK_GLOBAL_MUTEX;
+
+    if ( ! strchr(acellName,'.') ) {
+       cellnamelength=strlen(acellName);
+       dotcellname=malloc(cellnamelength+2);
+       memcpy(dotcellname,acellName,cellnamelength);
+       dotcellname[cellnamelength]='.';
+       dotcellname[cellnamelength+1]=0;
+       LOCK_GLOBAL_MUTEX;
+	    len = res_search(dotcellname, C_IN, T_AFSDB, answer, sizeof(answer));
+       if ( len < 0 ) {
+          len = res_search(acellName, C_IN, T_AFSDB, answer, sizeof(answer));
+       }
+       UNLOCK_GLOBAL_MUTEX;
+       free(dotcellname);
+    } else {
+       LOCK_GLOBAL_MUTEX;
+	    len = res_search(acellName, C_IN, T_AFSDB, answer, sizeof(answer));
+       UNLOCK_GLOBAL_MUTEX;
+    }
     if (len < 0)
 	return AFSCONF_NOTFOUND;
 
@@ -900,7 +917,7 @@ afsconf_GetCellInfo(struct afsconf_dir *adir, char *acellName, char *aservice,
     register afs_int32 i;
     int tservice;
     char *tcell;
-    size_t cnLen;
+    int cnLen;
     int ambig;
     char tbuffer[64];
 
@@ -909,7 +926,7 @@ afsconf_GetCellInfo(struct afsconf_dir *adir, char *acellName, char *aservice,
 	afsconf_Check(adir);
     if (acellName) {
 	tcell = acellName;
-	cnLen = strlen(tcell) + 1;
+	cnLen = (int)(strlen(tcell) + 1);
 	lcstring(tcell, tcell, cnLen);
 	afsconf_SawCell = 1;	/* will ignore the AFSCELL switch on future */
 	/* call to afsconf_GetLocalCell: like klog  */
@@ -1109,6 +1126,13 @@ afsconf_IntGetKeys(struct afsconf_dir *adir)
 
     /* convert key structure to host order */
     tstr->nkeys = ntohl(tstr->nkeys);
+
+    if (code < sizeof(afs_int32) + (tstr->nkeys*sizeof(struct afsconf_key))) {
+	tstr->nkeys = 0;
+	UNLOCK_GLOBAL_MUTEX;
+	return 0;
+    }
+
     for (fd = 0; fd < tstr->nkeys; fd++)
 	tstr->key[fd].kvno = ntohl(tstr->key[fd].kvno);
 
