@@ -11,10 +11,16 @@
 #include <afs/param.h>
 
 RCSID
-    ("$Header: /cvs/openafs/src/bucoord/commands.c,v 1.12 2003/11/23 04:53:30 jaltman Exp $");
+    ("$Header: /cvs/openafs/src/bucoord/commands.c,v 1.18 2006/04/11 19:27:03 shadow Exp $");
 
 #include <afs/stds.h>
+#if defined(AFS_LINUX24_ENV)
+#define _REGEX_RE_COMP
+#endif
 #include <sys/types.h>
+#if defined(AFS_LINUX24_ENV)
+#include <regex.h>
+#endif
 #include <afs/cmd.h>
 #ifdef AFS_NT40_ENV
 #include <winsock2.h>
@@ -45,7 +51,6 @@ RCSID
 
 
 extern struct bc_config *bc_globalConfig;
-extern char *ktime_GetDateUsage();
 extern struct bc_dumpSchedule *bc_FindDumpSchedule();
 extern struct bc_volumeSet *bc_FindVolumeSet(struct bc_config *cfg,
 					     char *name);
@@ -53,12 +58,7 @@ extern struct bc_dumpTask bc_dumpTasks[BC_MAXSIMDUMPS];
 extern struct ubik_client *cstruct;
 extern int bc_Dumper();		/* function to do dumps */
 extern int bc_Restorer();	/* function to do restores */
-extern void bc_HandleMisc();
-extern afs_int32 ScanDumpHdr();
-extern afs_int32 ScanTapeVolume();
 extern char *whoami;
-extern int VL_ListEntry();
-extern int VL_ListAttributesN2();
 extern struct ktc_token ttoken;
 extern char *tailCompPtr();
 extern statusP createStatusNode();
@@ -66,11 +66,7 @@ extern statusP createStatusNode();
 char *loadFile;
 extern afs_int32 lastTaskCode;
 
-#ifdef AFS_DEC_ENV
-#define HOSTADDR(sockaddr) (sockaddr)->sin_addr.S_un.S_addr
-#else
 #define HOSTADDR(sockaddr) (sockaddr)->sin_addr.s_addr
-#endif
 
 int
 bc_EvalVolumeSet(aconfig, avs, avols, uclient)
@@ -200,6 +196,7 @@ randSPEntries(serverlist, avols)
 	}
 	free(ss);
     }
+    return 0;
 }
 
 int
@@ -631,7 +628,8 @@ compactDateString(date_long, string, size)
     if (*date_long == NEVERDATE) {
 	sprintf(string, "NEVER");
     } else {
-	ltime = localtime(date_long);
+        time_t t = *date_long;
+	ltime = localtime(&t);
 	/* prints date in U.S. format of mm/dd/yyyy */
 	strftime(string, size, "%m/%d/%Y %H:%M", ltime);
     }
@@ -1966,7 +1964,7 @@ bc_DumpCmd(as, arock)
     code = bc_StartDmpRst(bc_globalConfig, dumpPath, vsName, volsToDump,
 			  /*destServer */ 0, /*destPartition */ 0,
 			  /*fromDate */ 0,
-			  /*newExt */ 0, /*oldFlag */ 0,
+			  /*newExt */ NULL, /*oldFlag */ 0,
 			  parent, level, bc_Dumper, portp, /*portCount */ 1,
 			  baseds, doAppend, dontExecute);
     if (code)
@@ -2907,13 +2905,14 @@ dumpInfo(dumpid, detailFlag)
 	printf("----\n");
 	printDumpEntry(&dumpEntry);
     } else {
+        time_t t = dumpEntry.created;
 	if (dbDump)
 	    printf("Dump: id %u, created: %s\n", dumpEntry.id,
-		   ctime(&dumpEntry.created));
-	else
+		   ctime(&t));
+ 	else
 	    printf("Dump: id %u, level %d, volumes %d, created: %s\n",
 		   dumpEntry.id, dumpEntry.level, dumpEntry.nVolumes,
-		   ctime(&dumpEntry.created));
+		   ctime(&t));
     }
 
     if (!detailFlag && (strlen(dumpEntry.tapes.tapeServer) > 0)
@@ -3066,6 +3065,7 @@ dumpInfo(dumpid, detailFlag)
     return (code);
 }
 
+int
 compareDump(ptr1, ptr2)
      struct budb_dumpEntry *ptr1, *ptr2;
 {
