@@ -14,6 +14,8 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
+RCSID
+    ("$Header: /cvs/openafs/src/bucoord/dump.c,v 1.13 2005/04/03 18:09:25 shadow Exp $");
 
 #include <sys/types.h>
 #include <afs/cmd.h>
@@ -21,6 +23,7 @@
 #include <winsock2.h>
 #else
 #include <sys/param.h>
+#include <strings.h>
 #include <sys/socket.h>
 #include <netinet/in.h>
 #include <netdb.h>
@@ -92,7 +95,7 @@ bc_Dumper(aindex)
     volDesc =
 	(struct tc_dumpDesc *)malloc(count * sizeof(struct tc_dumpDesc));
     if (!volDesc) {
-	afs_com_err(whoami, BC_NOMEM, "");
+	com_err(whoami, BC_NOMEM, "");
 	ERROR(BC_NOMEM);
     }
 
@@ -142,11 +145,11 @@ bc_Dumper(aindex)
     printf("Starting dump\n");
     code = TC_PerformDump(tconn, tcdiPtr, &volArray, &dumpTaskPtr->dumpID);
     if (code) {
-	afs_com_err(whoami, code, "; Failed to start dump");
+	com_err(whoami, code, "; Failed to start dump");
 	ERROR(code);
     }
 
-    afs_com_err(whoami, 0, "Task %u: Dump (%s)", dumpTaskPtr->dumpID,
+    com_err(whoami, 0, "Task %u: Dump (%s)", dumpTaskPtr->dumpID,
 	    tcdiPtr->dumpName);
 
     /* create status monitor block */
@@ -176,7 +179,6 @@ bc_Dumper(aindex)
  *	free the list of volumes used for dumps
  */
 
-void
 freeDumpTaskVolumeList(vdptr)
      struct bc_volumeDump *vdptr;
 {
@@ -197,10 +199,9 @@ freeDumpTaskVolumeList(vdptr)
  *     The other half of the dump/restore create process call. In bc_StartDmpRst, 
  *     we allocated a dumpTask entry. Here we do the task and then free the entry.
  */
-void *
-bc_DmpRstStart(void *param)
+bc_DmpRstStart(aindex)
+     afs_int32 aindex;
 {
-    afs_int32 aindex = (afs_int32) param;
     register struct bc_dumpTask *tdump;
     register afs_int32 code;
 
@@ -223,7 +224,7 @@ bc_DmpRstStart(void *param)
 	free(tdump->portOffset);
     tdump->flags &= ~BC_DI_INUSE;
 
-    return (void *)code;
+    return code;
 }
 
 /* bc_StartDmpRst
@@ -266,7 +267,7 @@ bc_StartDmpRst(aconfig, adname, avname, avolsToDump, adestServer,
 	    break;
 
     if (i >= BC_MAXSIMDUMPS) {
-	afs_com_err(whoami, BC_NOTLOCKED,
+	com_err(whoami, BC_NOTLOCKED,
 		"All of the dump/restore slots are in use, try again later");
 	return (BC_NOTLOCKED);
     }
@@ -305,7 +306,7 @@ bc_StartDmpRst(aconfig, adname, avname, avolsToDump, adestServer,
 			  (void *)i, "helper", &junk);
     if (code) {
 	bc_HandleMisc(code);
-	afs_com_err(whoami, code, "; Can't start thread");
+	com_err(whoami, code, "; Can't start thread");
 
 	/* Cleanup allocated data structures */
 	freeDumpTaskVolumeList(bc_dumpTasks[i].volumes);
@@ -384,7 +385,7 @@ bc_LabelTape(afsname, pname, size, config, port)
 
     code = TC_LabelTape(tconn, &label, &taskId);
     if (code) {
-	afs_com_err(whoami, code, "; Failed to start labeltape");
+	com_err(whoami, code, "; Failed to start labeltape");
 	return (code);
     }
 
@@ -430,7 +431,7 @@ bc_ReadLabel(config, port)
 	    printf("Tape read was unlabelled\n");
 	    return 0;
 	}
-	afs_com_err(whoami, code, "; Failed to start readlabel");
+	com_err(whoami, code, "; Failed to start readlabel");
 	return (code);
     }
 
@@ -468,7 +469,7 @@ bc_ScanDumps(config, dbAddFlag, port)
 
     code = TC_ScanDumps(tconn, dbAddFlag, &taskId);
     if (code) {
-	afs_com_err(whoami, code, "; Failed to start scantape");
+	com_err(whoami, code, "; Failed to start scantape");
 	return (code);
     }
 
@@ -559,7 +560,7 @@ ConnectButc(config, port, tconn)
 
     code = bc_GetConn(config, port, tconn);
     if (code) {
-	afs_com_err(whoami, code,
+	com_err(whoami, code,
 		"; Can't connect to tape coordinator at port %d", port);
 	return (code);
     }
@@ -569,10 +570,10 @@ ConnectButc(config, port, tconn)
 	rx_DestroyConnection(*tconn);
 
 	if (code == BC_VERSIONFAIL)
-	    afs_com_err(whoami, code,
+	    com_err(whoami, code,
 		    "; Backup and butc are not the same version");
 	else
-	    afs_com_err(whoami, code,
+	    com_err(whoami, code,
 		    "; Can't access tape coordinator at port %d", port);
 
 	return (code);
