@@ -16,7 +16,7 @@
 #include <afs/param.h>
 
 RCSID
-    ("$Header: /cvs/openafs/src/kauth/admin_tools.c,v 1.16.2.1 2004/08/25 07:03:39 shadow Exp $");
+    ("$Header: /cvs/openafs/src/kauth/admin_tools.c,v 1.19 2004/12/08 18:33:48 rees Exp $");
 
 #include <afs/stds.h>
 #include <afs/debug.h>
@@ -512,9 +512,9 @@ ka_islocked(char *name, char *instance, afs_uint32 * when)
     do {
 	tempwhen = 0;
 	code =
-	    ubik_CallIter(KAM_LockStatus, conn, UPUBIKONLY, &count, name,
-			  instance, &tempwhen, /*spares */ 0, 0, 0,
-			  0);
+	    ubik_CallIter(KAM_LockStatus, conn, UPUBIKONLY, &count, (long) name,
+			  (long) instance, (long) &tempwhen, 0, 0, 0,
+			  0, 0, 0, 0, 0, 0, 0, 0, 0, 0);
 	if (code) {
 	    if (seriouserror(code))
 		com_err(whoami, code, "");
@@ -549,8 +549,8 @@ Unlock(struct cmd_syndesc *as, char *arock)
 
     count = 0;
     do {
-	code = ubik_CallIter(KAM_Unlock, conn, 0, &count, name, instance,
-			     /*spares */ 0, 0, 0, 0);
+	code = ubik_CallIter(KAM_Unlock, conn, 0, &count, (long) name, (long) instance,
+			     0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0);
 	if (code && (code != UNOSERVERS)) {
 	    server = 0;
 	    if (conn && conn->conns[count - 1]
